ActionGeofenceSettingsPatterns extension

Adds pattern-matching-related methods to ActionGeofenceSettings.

on

Methods

map<TResult extends Object?>(TResult $default(_ActionGeofenceSettings value)) → TResult

Available on ActionGeofenceSettings, provided by the ActionGeofenceSettingsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ActionGeofenceSettings value)?) → TResult?

Available on ActionGeofenceSettings, provided by the ActionGeofenceSettingsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ActionGeofenceSettings value)?, {required TResult orElse()}) → TResult

Available on ActionGeofenceSettings, provided by the ActionGeofenceSettingsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(ActionProperty whoOwner, String? name, GeofenceCategory? category, double? radius, String? mappitRouteId, MappitRoute? mappitRoute)?, {required TResult orElse()}) → TResult

Available on ActionGeofenceSettings, provided by the ActionGeofenceSettingsPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(ActionProperty whoOwner, String? name, GeofenceCategory? category, double? radius, String? mappitRouteId, MappitRoute? mappitRoute)) → TResult

Available on ActionGeofenceSettings, provided by the ActionGeofenceSettingsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(ActionProperty whoOwner, String? name, GeofenceCategory? category, double? radius, String? mappitRouteId, MappitRoute? mappitRoute)?) → TResult?

Available on ActionGeofenceSettings, provided by the ActionGeofenceSettingsPatterns extension

A variant of when that fallback to returning null