AssetCommandPatterns extension

Adds pattern-matching-related methods to AssetCommand.

on

Methods

map<TResult extends Object?>(TResult $default(_AssetCommand value)) → TResult

Available on AssetCommand, provided by the AssetCommandPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AssetCommand value)?) → TResult?

Available on AssetCommand, provided by the AssetCommandPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AssetCommand value)?, {required TResult orElse()}) → TResult

Available on AssetCommand, provided by the AssetCommandPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String name, List<AssetCommandPossibleDevice> possibleDevices)?, {required TResult orElse()}) → TResult

Available on AssetCommand, provided by the AssetCommandPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String id, String name, List<AssetCommandPossibleDevice> possibleDevices)) → TResult

Available on AssetCommand, provided by the AssetCommandPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String name, List<AssetCommandPossibleDevice> possibleDevices)?) → TResult?

Available on AssetCommand, provided by the AssetCommandPatterns extension

A variant of when that fallback to returning null