AssetCommandPossibleDevice class abstract

Available extensions
Annotations
  • @freezed

Constructors

AssetCommandPossibleDevice({required String id, required String name, required String ident})
const
factory
AssetCommandPossibleDevice.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $AssetCommandPossibleDeviceCopyWith<AssetCommandPossibleDevice>
Create a copy of AssetCommandPossibleDevice with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
id is the id of the device.
no setterinherited
ident String
ident is the ident of the device.
no setterinherited
name String
name is the name of the device.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_AssetCommandPossibleDevice value)) → TResult

Available on AssetCommandPossibleDevice, provided by the AssetCommandPossibleDevicePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AssetCommandPossibleDevice value)?) → TResult?

Available on AssetCommandPossibleDevice, provided by the AssetCommandPossibleDevicePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AssetCommandPossibleDevice value)?, {required TResult orElse()}) → TResult

Available on AssetCommandPossibleDevice, provided by the AssetCommandPossibleDevicePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String name, String ident)?, {required TResult orElse()}) → TResult

Available on AssetCommandPossibleDevice, provided by the AssetCommandPossibleDevicePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this AssetCommandPossibleDevice to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String id, String name, String ident)) → TResult

Available on AssetCommandPossibleDevice, provided by the AssetCommandPossibleDevicePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String name, String ident)?) → TResult?

Available on AssetCommandPossibleDevice, provided by the AssetCommandPossibleDevicePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited