AssetWidgetInput class abstract
AssetWidgetInput is the mutable counterpart of AssetWidget, sent through the
updateAssetWidgets mutation.
- Available extensions
- Annotations
-
- @unfreezed
Constructors
- AssetWidgetInput({required String device, @JsonKey.new(unknownEnumValue: RenderWidget.unknown) required RenderWidget widget, required String expose, required AssetWidgetConfigInput config})
-
factory
-
AssetWidgetInput.fromJson(Map<
String, dynamic> json) -
factory
Properties
- config ↔ AssetWidgetConfigInput
-
getter/setter pairinherited
-
copyWith
→ $AssetWidgetInputCopyWith<
AssetWidgetInput> -
Create a copy of AssetWidgetInput
with the given fields replaced by the non-null parameter values.
no setterinherited
- device ↔ String
-
getter/setter pairinherited
- expose ↔ String
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget ↔ RenderWidget
-
getter/setter pairinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_AssetWidgetInput value)) → TResult -
Available on AssetWidgetInput, provided by the AssetWidgetInputPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_AssetWidgetInput value)?) → TResult? -
Available on AssetWidgetInput, provided by the AssetWidgetInputPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_AssetWidgetInput value)?, {required TResult orElse()}) → TResult -
Available on AssetWidgetInput, provided by the AssetWidgetInputPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String device, RenderWidget widget, String expose, AssetWidgetConfigInput config)?, {required TResult orElse()}) → TResult -
Available on AssetWidgetInput, provided by the AssetWidgetInputPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this AssetWidgetInput to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String device, RenderWidget widget, String expose, AssetWidgetConfigInput config)) → TResult -
Available on AssetWidgetInput, provided by the AssetWidgetInputPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String device, RenderWidget widget, String expose, AssetWidgetConfigInput config)?) → TResult? -
Available on AssetWidgetInput, provided by the AssetWidgetInputPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited