AtsDestinyInformationPatterns extension

Adds pattern-matching-related methods to AtsDestinyInformation.

on

Methods

map<TResult extends Object?>(TResult $default(_AtsDestinyInformation value)) → TResult

Available on AtsDestinyInformation, provided by the AtsDestinyInformationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AtsDestinyInformation value)?) → TResult?

Available on AtsDestinyInformation, provided by the AtsDestinyInformationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AtsDestinyInformation value)?, {required TResult orElse()}) → TResult

Available on AtsDestinyInformation, provided by the AtsDestinyInformationPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(double? capacity, double? replesnishOrWithdraw, AtsSetaVerification? destinyInformationSetaVerification)?, {required TResult orElse()}) → TResult

Available on AtsDestinyInformation, provided by the AtsDestinyInformationPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(double? capacity, double? replesnishOrWithdraw, AtsSetaVerification? destinyInformationSetaVerification)) → TResult

Available on AtsDestinyInformation, provided by the AtsDestinyInformationPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(double? capacity, double? replesnishOrWithdraw, AtsSetaVerification? destinyInformationSetaVerification)?) → TResult?

Available on AtsDestinyInformation, provided by the AtsDestinyInformationPatterns extension

A variant of when that fallback to returning null