BillingPlanInput class abstract

Available extensions
Annotations
  • @unfreezed

Constructors

BillingPlanInput({String? id, @Default.new(0.0) double reconnectionPercent, @Default.new(0) int reconnectionMaximum, @Default.new(0) int reconnectionIncidents, @Default.new(0) int maxAssets, @Default.new(0) int maxDevices, @Default.new(0) int maxUsers, @Default.new(0) int maxOutboundServices, @Default.new(0) int maxFunctions, @Default.new(0) int maxApps, @Default.new([]) List<String> allowedAppsIds, @Default.new([]) List<String> allowedAlgorithmsIds, @Default.new([]) List<String> allowedInboundProtocolsIds, @Default.new([]) List<String> allowedOutboundProtocolsIds, @Default.new([]) List<String> allowedVisionProtocolsIds, @Default.new([]) List<String> allowedExchangeProtocolsIds, @Default.new(false) bool aiEnabled})
factory
BillingPlanInput.fromJson(Map<String, dynamic> json)
factory

Properties

aiEnabled bool
aiEnabled is a boolean indicating if AI is enabled for the billing plan.
getter/setter pairinherited
allowedAlgorithmsIds List<String>
allowedAlgorithmsIds is the list of allowed algorithm IDs for the billing plan.
getter/setter pairinherited
allowedAppsIds List<String>
allowedAppsIds is the list of allowed app IDs for the billing plan.
getter/setter pairinherited
allowedExchangeProtocolsIds List<String>
allowedExchangeProtocolsIds is the list of allowed exchange protocol IDs for the billing plan.
getter/setter pairinherited
allowedInboundProtocolsIds List<String>
allowedInboundProtocolsIds is the list of allowed inbound protocol IDs for the billing plan.
getter/setter pairinherited
allowedOutboundProtocolsIds List<String>
allowedOutboundProtocolsIds is the list of allowed outbound protocol IDs for the billing plan.
getter/setter pairinherited
allowedVisionProtocolsIds List<String>
allowedVisionProtocolsIds is the list of allowed vision protocol IDs for the billing plan.
getter/setter pairinherited
copyWith → $BillingPlanInputCopyWith<BillingPlanInput>
Create a copy of BillingPlanInput with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
id is the unique identifier for the billing plan.
getter/setter pairinherited
maxApps int
maxApps is the maximum number of apps allowed for the billing plan.
getter/setter pairinherited
maxAssets int
maxAssets is the maximum number of assets allowed for the billing plan.
getter/setter pairinherited
maxDevices int
maxDevices is the maximum number of devices allowed for the billing plan.
getter/setter pairinherited
maxFunctions int
maxFunctions is the maximum number of functions allowed for the billing plan.
getter/setter pairinherited
maxOutboundServices int
maxOutboundServices is the maximum number of outbound services allowed for the billing plan.
getter/setter pairinherited
maxUsers int
maxUsers is the maximum number of users allowed for the billing plan.
getter/setter pairinherited
reconnectionIncidents int
reconnectionIncidents is the number of reconnection incidents allowed for the billing plan.
getter/setter pairinherited
reconnectionMaximum int
reconnectionMaximum is the maximum number of reconnections allowed for the billing plan.
getter/setter pairinherited
reconnectionPercent double
reconnectionPercent is the percentage of reconnections allowed for the billing plan.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_BillingPlanInput value)) → TResult

Available on BillingPlanInput, provided by the BillingPlanInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_BillingPlanInput value)?) → TResult?

Available on BillingPlanInput, provided by the BillingPlanInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_BillingPlanInput value)?, {required TResult orElse()}) → TResult

Available on BillingPlanInput, provided by the BillingPlanInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? id, double reconnectionPercent, int reconnectionMaximum, int reconnectionIncidents, int maxAssets, int maxDevices, int maxUsers, int maxOutboundServices, int maxFunctions, int maxApps, List<String> allowedAppsIds, List<String> allowedAlgorithmsIds, List<String> allowedInboundProtocolsIds, List<String> allowedOutboundProtocolsIds, List<String> allowedVisionProtocolsIds, List<String> allowedExchangeProtocolsIds, bool aiEnabled)?, {required TResult orElse()}) → TResult

Available on BillingPlanInput, provided by the BillingPlanInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this BillingPlanInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? id, double reconnectionPercent, int reconnectionMaximum, int reconnectionIncidents, int maxAssets, int maxDevices, int maxUsers, int maxOutboundServices, int maxFunctions, int maxApps, List<String> allowedAppsIds, List<String> allowedAlgorithmsIds, List<String> allowedInboundProtocolsIds, List<String> allowedOutboundProtocolsIds, List<String> allowedVisionProtocolsIds, List<String> allowedExchangeProtocolsIds, bool aiEnabled)) → TResult

Available on BillingPlanInput, provided by the BillingPlanInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? id, double reconnectionPercent, int reconnectionMaximum, int reconnectionIncidents, int maxAssets, int maxDevices, int maxUsers, int maxOutboundServices, int maxFunctions, int maxApps, List<String> allowedAppsIds, List<String> allowedAlgorithmsIds, List<String> allowedInboundProtocolsIds, List<String> allowedOutboundProtocolsIds, List<String> allowedVisionProtocolsIds, List<String> allowedExchangeProtocolsIds, bool aiEnabled)?) → TResult?

Available on BillingPlanInput, provided by the BillingPlanInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited