maxUsers property
maxUsers is the maximum number of users allowed for the billing plan.
Implementation
set maxDevices(int value);/// [maxUsers] is the maximum number of users allowed for the billing plan.
int get maxUsers;
maxUsers is the maximum number of users allowed for the billing plan.
Implementation
int get maxUsers;/// [maxUsers] is the maximum number of users allowed for the billing plan.
set maxUsers(int value);