BleService class abstract

Available extensions
Annotations
  • @freezed

Constructors

BleService({required String uuid, List<BleCharacteristic>? characteristics})
BleService is the representation of a BLE service.
const
factory
BleService.fromJson(Map<String, dynamic> json)
factory

Properties

characteristics List<BleCharacteristic>?
characteristics is the list of characteristics of the BLE service.
no setterinherited
copyWith → $BleServiceCopyWith<BleService>
Create a copy of BleService with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uuid String
uuid is the UUID of the BLE service.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_BleService value)) → TResult

Available on BleService, provided by the BleServicePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_BleService value)?) → TResult?

Available on BleService, provided by the BleServicePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_BleService value)?, {required TResult orElse()}) → TResult

Available on BleService, provided by the BleServicePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String uuid, List<BleCharacteristic>? characteristics)?, {required TResult orElse()}) → TResult

Available on BleService, provided by the BleServicePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this BleService to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String uuid, List<BleCharacteristic>? characteristics)) → TResult

Available on BleService, provided by the BleServicePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String uuid, List<BleCharacteristic>? characteristics)?) → TResult?

Available on BleService, provided by the BleServicePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited