CaclEntity class abstract

A model class representing a cacl entity.

Available extensions
Annotations
  • @freezed

Constructors

CaclEntity({String? id, String? assetId, Asset? asset, String? transportAssetId, Asset? transportAsset, String? transportUserId, User? transportUser, String? caclNumber, @JsonKey.new(unknownEnumValue: CaclCategory.load) CaclCategory? category, String? product, String? clientAssetId, Asset? clientAsset, String? origin, String? tankNumber, String? transport, CaclEquipmentEntity? equipments, MeasurementsEntity? measurements, ResultsEntity? results, CaclMeasurementOutput? measurer01, CaclMeasurementOutput? measurer02, VolumeMovedEntity? volumeMoved, String? observations, @TimestampOrNullConverter() DateTime? startedAt, @TimestampOrNullConverter() DateTime? finishedAt, @TimestampOrNullConverter() DateTime? createdAt, String? createdByUserId, User? createdByUser, String? operationId, AtsOperation? operation, @TimestampOrNullConverter() DateTime? localDateStart, @TimestampOrNullConverter() DateTime? localDateEnd, double? lossPercentage, bool? isCombine, Asset? tankAsset, @TimestampOrNullConverter() DateTime? signedAt, CaclTFBDetails? tfbDetails})
Creates a new CaclEntity instance.
factory
CaclEntity.fromJson(Map<String, dynamic> json)
Creates a new CaclEntity instance from a JSON map.
factory

Properties

asset Asset?
The asset parameter is the asset of the cacl entity.
no setterinherited
assetId String?
The assetId parameter is the assetId of the cacl entity.
no setterinherited
caclNumber String?
The caclNumber parameter is the caclNumber of the cacl entity.
no setterinherited
category CaclCategory?
The category parameter is the category of the cacl entity.
no setterinherited
clientAsset Asset?
The clientAsset parameter is the clientAsset of the cacl entity.
no setterinherited
clientAssetId String?
The clientAssetId parameter is the clientAssetId of the cacl entity.
no setterinherited
copyWith → $CaclEntityCopyWith<CaclEntity>
Create a copy of CaclEntity with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt DateTime?
The createdAt parameter is the createdAt of the cacl entity.
no setterinherited
createdByUser User?
The createdByUser parameter is the user who created the cacl entity.
no setterinherited
createdByUserId String?
The createdByUserId parameter is the id of the user who created the cacl entity.
no setterinherited
equipments CaclEquipmentEntity?
The equipments parameter is the equipments of the cacl entity.
no setterinherited
finishedAt DateTime?
The finishedAt parameter is the finishedAt of the cacl entity.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
The id parameter is the id of the cacl entity.
no setterinherited
isCombine bool?
isCombine indicates if the cacl is a combined form.
no setterinherited
localDateEnd DateTime?
localDateEnd is the local date end of the cacl entity.
no setterinherited
localDateStart DateTime?
localDateStart is the local date start of the cacl entity.
no setterinherited
lossPercentage double?
lossPercentage is the loss percentage of the cacl entity.
no setterinherited
measurements MeasurementsEntity?
The measurements parameter is the measurements of the cacl entity.
no setterinherited
measurer01 CaclMeasurementOutput?
The measurer01 parameter is the measurer01 of the cacl entity.
no setterinherited
measurer02 CaclMeasurementOutput?
The measurer02 parameter is the measurer02 of the cacl entity.
no setterinherited
observations String?
The observations parameter is the observations of the cacl entity.
no setterinherited
operation AtsOperation?
The operation parameter is the operation of the cacl entity.
no setterinherited
operationId String?
The operationId parameter is the operationId of the cacl entity.
no setterinherited
origin String?
The origin parameter is the origin of the cacl entity.
no setterinherited
product String?
The product parameter is the product of the cacl entity.
no setterinherited
results ResultsEntity?
The results parameter is the results of the cacl entity.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signedAt DateTime?
The signedAt parameter is the signedAt of the cacl entity.
no setterinherited
startedAt DateTime?
The startedAt parameter is the startedAt of the cacl entity.
no setterinherited
tankAsset Asset?
The tankAsset parameter is the tankAsset of the cacl entity.
no setterinherited
tankNumber String?
The tankNumber parameter is the tankNumber of the cacl entity.
no setterinherited
tfbDetails CaclTFBDetails?
The tfbDetails parameter is the tfbDetails of the cacl entity.
no setterinherited
transport String?
The transport parameter is the transport of the cacl entity.
no setterinherited
transportAsset Asset?
The transportAsset parameter is the transportAsset of the cacl entity.
no setterinherited
transportAssetId String?
The transportAssetId parameter is the transportAssetId of the cacl entity.
no setterinherited
transportUser User?
The transportUser parameter is the transportUser of the cacl entity.
no setterinherited
transportUserId String?
The transportUserId parameter is the transportUserId of the cacl entity.
no setterinherited
volumeMoved VolumeMovedEntity?
The volumeMoved parameter is the volumeMoved of the cacl entity.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CaclEntity value)) → TResult

Available on CaclEntity, provided by the CaclEntityPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CaclEntity value)?) → TResult?

Available on CaclEntity, provided by the CaclEntityPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CaclEntity value)?, {required TResult orElse()}) → TResult

Available on CaclEntity, provided by the CaclEntityPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? id, String? assetId, Asset? asset, String? transportAssetId, Asset? transportAsset, String? transportUserId, User? transportUser, String? caclNumber, CaclCategory? category, String? product, String? clientAssetId, Asset? clientAsset, String? origin, String? tankNumber, String? transport, CaclEquipmentEntity? equipments, MeasurementsEntity? measurements, ResultsEntity? results, CaclMeasurementOutput? measurer01, CaclMeasurementOutput? measurer02, VolumeMovedEntity? volumeMoved, String? observations, DateTime? startedAt, DateTime? finishedAt, DateTime? createdAt, String? createdByUserId, User? createdByUser, String? operationId, AtsOperation? operation, DateTime? localDateStart, DateTime? localDateEnd, double? lossPercentage, bool? isCombine, Asset? tankAsset, DateTime? signedAt, CaclTFBDetails? tfbDetails)?, {required TResult orElse()}) → TResult

Available on CaclEntity, provided by the CaclEntityPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CaclEntity to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? id, String? assetId, Asset? asset, String? transportAssetId, Asset? transportAsset, String? transportUserId, User? transportUser, String? caclNumber, CaclCategory? category, String? product, String? clientAssetId, Asset? clientAsset, String? origin, String? tankNumber, String? transport, CaclEquipmentEntity? equipments, MeasurementsEntity? measurements, ResultsEntity? results, CaclMeasurementOutput? measurer01, CaclMeasurementOutput? measurer02, VolumeMovedEntity? volumeMoved, String? observations, DateTime? startedAt, DateTime? finishedAt, DateTime? createdAt, String? createdByUserId, User? createdByUser, String? operationId, AtsOperation? operation, DateTime? localDateStart, DateTime? localDateEnd, double? lossPercentage, bool? isCombine, Asset? tankAsset, DateTime? signedAt, CaclTFBDetails? tfbDetails)) → TResult

Available on CaclEntity, provided by the CaclEntityPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? id, String? assetId, Asset? asset, String? transportAssetId, Asset? transportAsset, String? transportUserId, User? transportUser, String? caclNumber, CaclCategory? category, String? product, String? clientAssetId, Asset? clientAsset, String? origin, String? tankNumber, String? transport, CaclEquipmentEntity? equipments, MeasurementsEntity? measurements, ResultsEntity? results, CaclMeasurementOutput? measurer01, CaclMeasurementOutput? measurer02, VolumeMovedEntity? volumeMoved, String? observations, DateTime? startedAt, DateTime? finishedAt, DateTime? createdAt, String? createdByUserId, User? createdByUser, String? operationId, AtsOperation? operation, DateTime? localDateStart, DateTime? localDateEnd, double? lossPercentage, bool? isCombine, Asset? tankAsset, DateTime? signedAt, CaclTFBDetails? tfbDetails)?) → TResult?

Available on CaclEntity, provided by the CaclEntityPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited