CaclInput class sealed

A model class representing a cacl input.

Available extensions
Annotations
  • @unfreezed

Constructors

CaclInput({String? id, String? assetId, String? transportAssetId, String? transportUserId, String? caclNumber, @JsonKey.new(unknownEnumValue: CaclCategory.load) CaclCategory? category, String? product, String? clientAssetId, String? tankNumber, String? transport, CaclEquipmentInput? equipments, MeasurementsInput? measurements, ResultsInput? results, CaclMeasurement? measurer01, CaclMeasurement? measurer02, VolumeMovedInput? volumeMoved, String? observations, @TimestampOrNullConverter() DateTime? startedAt, @TimestampOrNullConverter() DateTime? finishedAt, String? operationId, @TimestampOrNullConverter() DateTime? localDateStart, @TimestampOrNullConverter() DateTime? localDateEnd, CaclTFBDetailsInput? tfbDetails})
factory
CaclInput.fromJson(Map<String, dynamic> json)
Creates a new CaclInput instance from a JSON map.
factory

Properties

assetId String?
The assetId parameter is the assetId of the cacl input.
getter/setter pairinherited
caclNumber String?
The caclNumber parameter is the caclNumber of the cacl input.
getter/setter pairinherited
category CaclCategory?
The category parameter is the category of the cacl input.
getter/setter pairinherited
clientAssetId String?
The clientAssetId parameter is the clientAssetId of the cacl input.
getter/setter pairinherited
copyWith → $CaclInputCopyWith<CaclInput>
Create a copy of CaclInput with the given fields replaced by the non-null parameter values.
no setterinherited
equipments CaclEquipmentInput?
The equipments parameter is the equipments of the cacl input.
getter/setter pairinherited
finishedAt DateTime?
The finishedAt parameter is the finishedAt of the cacl input.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
The id parameter is the id of the cacl input.
getter/setter pairinherited
localDateEnd DateTime?
localDateEnd is the local date end of the cacl input.
getter/setter pairinherited
localDateStart DateTime?
localDateStart is the local date start of the cacl input.
getter/setter pairinherited
measurements MeasurementsInput?
The measurements parameter is the measurements of the cacl input.
getter/setter pairinherited
measurer01 CaclMeasurement?
The measurer01 parameter is the measurer01 of the cacl input.
getter/setter pairinherited
measurer02 CaclMeasurement?
The measurer02 parameter is the measurer02 of the cacl input.
getter/setter pairinherited
observations String?
The observations parameter is the observations of the cacl input.
getter/setter pairinherited
operationId String?
The operationId parameter is the operationId of the cacl entity.
getter/setter pairinherited
product String?
The product parameter is the product of the cacl input.
getter/setter pairinherited
results ResultsInput?
The results parameter is the results of the cacl input.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt DateTime?
The startedAt parameter is the startedAt of the cacl input.
getter/setter pairinherited
tankNumber String?
The tankNumber parameter is the tankNumber of the cacl input.
getter/setter pairinherited
tfbDetails CaclTFBDetailsInput?
The tfbDetails parameter is the tfbDetails of the cacl input.
getter/setter pairinherited
transport String?
The transport parameter is the transport of the cacl input.
getter/setter pairinherited
transportAssetId String?
The transportAssetId parameter is the transportAssetId of the cacl input.
getter/setter pairinherited
transportUserId String?
The transportUserId parameter is the transportUserId of the cacl input.
getter/setter pairinherited
volumeMoved VolumeMovedInput?
The volumeMoved parameter is the volumeMoved of the cacl input.
getter/setter pairinherited

Methods

map<TResult extends Object?>(TResult $default(_CaclInput value)) → TResult

Available on CaclInput, provided by the CaclInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CaclInput value)?) → TResult?

Available on CaclInput, provided by the CaclInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CaclInput value)?, {required TResult orElse()}) → TResult

Available on CaclInput, provided by the CaclInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? id, String? assetId, String? transportAssetId, String? transportUserId, String? caclNumber, CaclCategory? category, String? product, String? clientAssetId, String? tankNumber, String? transport, CaclEquipmentInput? equipments, MeasurementsInput? measurements, ResultsInput? results, CaclMeasurement? measurer01, CaclMeasurement? measurer02, VolumeMovedInput? volumeMoved, String? observations, DateTime? startedAt, DateTime? finishedAt, String? operationId, DateTime? localDateStart, DateTime? localDateEnd, CaclTFBDetailsInput? tfbDetails)?, {required TResult orElse()}) → TResult

Available on CaclInput, provided by the CaclInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CaclInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? id, String? assetId, String? transportAssetId, String? transportUserId, String? caclNumber, CaclCategory? category, String? product, String? clientAssetId, String? tankNumber, String? transport, CaclEquipmentInput? equipments, MeasurementsInput? measurements, ResultsInput? results, CaclMeasurement? measurer01, CaclMeasurement? measurer02, VolumeMovedInput? volumeMoved, String? observations, DateTime? startedAt, DateTime? finishedAt, String? operationId, DateTime? localDateStart, DateTime? localDateEnd, CaclTFBDetailsInput? tfbDetails)) → TResult

Available on CaclInput, provided by the CaclInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? id, String? assetId, String? transportAssetId, String? transportUserId, String? caclNumber, CaclCategory? category, String? product, String? clientAssetId, String? tankNumber, String? transport, CaclEquipmentInput? equipments, MeasurementsInput? measurements, ResultsInput? results, CaclMeasurement? measurer01, CaclMeasurement? measurer02, VolumeMovedInput? volumeMoved, String? observations, DateTime? startedAt, DateTime? finishedAt, String? operationId, DateTime? localDateStart, DateTime? localDateEnd, CaclTFBDetailsInput? tfbDetails)?) → TResult?

Available on CaclInput, provided by the CaclInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited