CareTask class abstract

Available extensions
Annotations
  • @freezed

Constructors

CareTask({required String question, @JsonKey.new(unknownEnumValue: AnswerKind.text) required AnswerKind answer, @Default.new([]) List<String> choices, @Default.new(0) int minValue, @Default.new(0) int maxValue})
const
factory
CareTask.fromJson(Map<String, dynamic> json)
factory

Properties

answer AnswerKind
Is the type of answer
no setterinherited
choices List<String>
When answer = AnswerKind.choice, choices represents the list of possible values
no setterinherited
copyWith → $CareTaskCopyWith<CareTask>
Create a copy of CareTask with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
maxValue int
no setterinherited
minValue int
When answer = AnswerKind.range, minValue and maxValue represents the range of possible values
no setterinherited
question String
Is the question to prompt
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CareTask value)) → TResult

Available on CareTask, provided by the CareTaskPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CareTask value)?) → TResult?

Available on CareTask, provided by the CareTaskPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CareTask value)?, {required TResult orElse()}) → TResult

Available on CareTask, provided by the CareTaskPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String question, AnswerKind answer, List<String> choices, int minValue, int maxValue)?, {required TResult orElse()}) → TResult

Available on CareTask, provided by the CareTaskPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CareTask to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String question, AnswerKind answer, List<String> choices, int minValue, int maxValue)) → TResult

Available on CareTask, provided by the CareTaskPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String question, AnswerKind answer, List<String> choices, int minValue, int maxValue)?) → TResult?

Available on CareTask, provided by the CareTaskPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited