ColorblindMode enum

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

protanopia → const ColorblindMode

protanopia is the red-blind colorblindness.

protanomaly → const ColorblindMode

protanomaly is the red-weak colorblindness.

deuteranopia → const ColorblindMode

deuteranopia is the green-blind colorblindness.

deuteranomaly → const ColorblindMode

deuteranomaly is the green-weak colorblindness.

tritanopia → const ColorblindMode

tritanopia is the blue-blind colorblindness.

tritanomaly → const ColorblindMode

tritanomaly is the blue-weak colorblindness.

normal → const ColorblindMode

normal is the normal vision. No colorblindness.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(String json) ColorblindMode

Constants

values → const List<ColorblindMode>
A constant List of the values in this enum, in order of their declaration.