ConciergeBlockInputPatterns extension

Adds pattern-matching-related methods to ConciergeBlockInput.

on

Methods

map<TResult extends Object?>(TResult $default(_ConciergeBlockInput value)) → TResult

Available on ConciergeBlockInput, provided by the ConciergeBlockInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ConciergeBlockInput value)?) → TResult?

Available on ConciergeBlockInput, provided by the ConciergeBlockInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ConciergeBlockInput value)?, {required TResult orElse()}) → TResult

Available on ConciergeBlockInput, provided by the ConciergeBlockInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String name, ConciergeFormBlockType blockType, ConciergeFormBlockDisplayConditionInput? showWhen, ConciergeFormBlockConfigurationInput? configuration)?, {required TResult orElse()}) → TResult

Available on ConciergeBlockInput, provided by the ConciergeBlockInputPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String name, ConciergeFormBlockType blockType, ConciergeFormBlockDisplayConditionInput? showWhen, ConciergeFormBlockConfigurationInput? configuration)) → TResult

Available on ConciergeBlockInput, provided by the ConciergeBlockInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String name, ConciergeFormBlockType blockType, ConciergeFormBlockDisplayConditionInput? showWhen, ConciergeFormBlockConfigurationInput? configuration)?) → TResult?

Available on ConciergeBlockInput, provided by the ConciergeBlockInputPatterns extension

A variant of when that fallback to returning null