CountryState class abstract

Available extensions
Annotations
  • @freezed

Constructors

CountryState({required String id, @JsonKey.new(name: 'nativeName') required String name, required String code})
const
factory
CountryState.fromJson(Map<String, dynamic> json)
factory

Properties

code String
code represents the code of the CountryState
no setterinherited
copyWith → $CountryStateCopyWith<CountryState>
Create a copy of CountryState with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
id represents the unique identifier of the CountryState
no setterinherited
name String
name represents the name of the CountryState
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CountryState value)) → TResult

Available on CountryState, provided by the CountryStatePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CountryState value)?) → TResult?

Available on CountryState, provided by the CountryStatePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CountryState value)?, {required TResult orElse()}) → TResult

Available on CountryState, provided by the CountryStatePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String name, String code)?, {required TResult orElse()}) → TResult

Available on CountryState, provided by the CountryStatePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CountryState to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String id, String name, String code)) → TResult

Available on CountryState, provided by the CountryStatePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String name, String code)?) → TResult?

Available on CountryState, provided by the CountryStatePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited