CustomReport class abstract

Available extensions
Annotations
  • @freezed

Constructors

CustomReport({required String id, required String code, List<RegisteredApp>? allowedApps})
const
factory
CustomReport.fromJson(Map<String, dynamic> json)
factory

Properties

allowedApps List<RegisteredApp>?
allowedApps is the list of allowed apps
no setterinherited
code String
code is the report code
no setterinherited
copyWith → $CustomReportCopyWith<CustomReport>
Create a copy of CustomReport with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
id is the report ID
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CustomReport value)) → TResult

Available on CustomReport, provided by the CustomReportPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CustomReport value)?) → TResult?

Available on CustomReport, provided by the CustomReportPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CustomReport value)?, {required TResult orElse()}) → TResult

Available on CustomReport, provided by the CustomReportPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String code, List<RegisteredApp>? allowedApps)?, {required TResult orElse()}) → TResult

Available on CustomReport, provided by the CustomReportPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CustomReport to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String id, String code, List<RegisteredApp>? allowedApps)) → TResult

Available on CustomReport, provided by the CustomReportPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String code, List<RegisteredApp>? allowedApps)?) → TResult?

Available on CustomReport, provided by the CustomReportPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited