EmployeeInput class abstract
- Available extensions
- Annotations
-
- @unfreezed
Constructors
- EmployeeInput({String? id, @Default.new('') String name, @Default.new('') String email, @Default.new('') String username, String? departmentId, AvatarInput? dynamicAvatar, required GenericPermissionInput customPermissions})
-
factory
-
EmployeeInput.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $EmployeeInputCopyWith<
EmployeeInput> -
Create a copy of EmployeeInput
with the given fields replaced by the non-null parameter values.
no setterinherited
- customPermissions ↔ GenericPermissionInput
-
getter/setter pairinherited
- departmentId ↔ String?
-
getter/setter pairinherited
- dynamicAvatar ↔ AvatarInput?
-
getter/setter pairinherited
- email ↔ String
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
getter/setter pairinherited
- name ↔ String
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- username ↔ String
-
getter/setter pairinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_EmployeeInput value)) → TResult -
Available on EmployeeInput, provided by the EmployeeInputPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_EmployeeInput value)?) → TResult? -
Available on EmployeeInput, provided by the EmployeeInputPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_EmployeeInput value)?, {required TResult orElse()}) → TResult -
Available on EmployeeInput, provided by the EmployeeInputPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? id, String name, String email, String username, String? departmentId, AvatarInput? dynamicAvatar, GenericPermissionInput customPermissions)?, {required TResult orElse()}) → TResult -
Available on EmployeeInput, provided by the EmployeeInputPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this EmployeeInput to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? id, String name, String email, String username, String? departmentId, AvatarInput? dynamicAvatar, GenericPermissionInput customPermissions)) → TResult -
Available on EmployeeInput, provided by the EmployeeInputPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? id, String name, String email, String username, String? departmentId, AvatarInput? dynamicAvatar, GenericPermissionInput customPermissions)?) → TResult? -
Available on EmployeeInput, provided by the EmployeeInputPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited