GeofencePointInput class abstract
- Available extensions
- Annotations
-
- @unfreezed
Constructors
- GeofencePointInput({required double latitude, required double longitude})
-
factory
-
GeofencePointInput.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $GeofencePointInputCopyWith<
GeofencePointInput> -
Create a copy of GeofencePointInput
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- latitude ↔ double
-
getter/setter pairinherited
- longitude ↔ double
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toLatLng → LatLng
-
no setter
Methods
-
map<
TResult extends Object?> (TResult $default(_GeofencePointInput value)) → TResult -
Available on GeofencePointInput, provided by the GeofencePointInputPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_GeofencePointInput value)?) → TResult? -
Available on GeofencePointInput, provided by the GeofencePointInputPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_GeofencePointInput value)?, {required TResult orElse()}) → TResult -
Available on GeofencePointInput, provided by the GeofencePointInputPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(double latitude, double longitude)?, {required TResult orElse()}) → TResult -
Available on GeofencePointInput, provided by the GeofencePointInputPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this GeofencePointInput to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(double latitude, double longitude)) → TResult -
Available on GeofencePointInput, provided by the GeofencePointInputPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(double latitude, double longitude)?) → TResult? -
Available on GeofencePointInput, provided by the GeofencePointInputPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited