InboundPositionStructureInput class abstract

Available extensions
Annotations
  • @unfreezed

Constructors

InboundPositionStructureInput({@Default.new(true) bool latitude, @Default.new(true) bool longitude, @Default.new(true) bool speed, @Default.new(true) bool direction, @Default.new(true) bool altitude, @Default.new(true) bool satellites, @Default.new(true) bool hdop})
factory
InboundPositionStructureInput.fromJson(Map<String, dynamic> json)
factory

Properties

altitude bool
getter/setter pairinherited
copyWith → $InboundPositionStructureInputCopyWith<InboundPositionStructureInput>
Create a copy of InboundPositionStructureInput with the given fields replaced by the non-null parameter values.
no setterinherited
direction bool
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hdop bool
getter/setter pairinherited
latitude bool
getter/setter pairinherited
longitude bool
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
satellites bool
getter/setter pairinherited
speed bool
getter/setter pairinherited

Methods

map<TResult extends Object?>(TResult $default(_InboundPositionStructureInput value)) → TResult

Available on InboundPositionStructureInput, provided by the InboundPositionStructureInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_InboundPositionStructureInput value)?) → TResult?

Available on InboundPositionStructureInput, provided by the InboundPositionStructureInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_InboundPositionStructureInput value)?, {required TResult orElse()}) → TResult

Available on InboundPositionStructureInput, provided by the InboundPositionStructureInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool latitude, bool longitude, bool speed, bool direction, bool altitude, bool satellites, bool hdop)?, {required TResult orElse()}) → TResult

Available on InboundPositionStructureInput, provided by the InboundPositionStructureInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this InboundPositionStructureInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool latitude, bool longitude, bool speed, bool direction, bool altitude, bool satellites, bool hdop)) → TResult

Available on InboundPositionStructureInput, provided by the InboundPositionStructureInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool latitude, bool longitude, bool speed, bool direction, bool altitude, bool satellites, bool hdop)?) → TResult?

Available on InboundPositionStructureInput, provided by the InboundPositionStructureInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited