whenOrNull<TResult extends Object?> method
TResult?
whenOrNull<TResult extends Object?>()
A variant of when that fallback to returning null
It is equivalent to doing:
switch (sealedClass) {
case Subclass(:final field):
return ...;
case _:
return null;
}
Implementation
@optionalTypeArgs TResult? whenOrNull<TResult extends Object?>(TResult? Function( bool latitude, bool longitude, bool speed, bool direction, bool altitude, bool satellites, bool hdop)? $default,) {final _that = this;
switch (_that) {
case _InboundPositionStructureInput() when $default != null:
return $default(_that.latitude,_that.longitude,_that.speed,_that.direction,_that.altitude,_that.satellites,_that.hdop);case _:
return null;
}
}