InboundProtocolInput class abstract

Available extensions
Annotations
  • @unfreezed

Constructors

InboundProtocolInput({String? id, @Default.new('') String name, @ColorConverter() @Default.new(Colors.blue) Color color, @Default.new(true) bool isEnabled, @Default.new([]) List<String> categoriesIds, @JsonKey.new(unknownEnumValue: OperationMode.unknown) @Default.new(OperationMode.realtime) OperationMode operationMode, @Default.new(false) bool hasNativeCommands, @Default.new(false) bool hasSmsCommands, @Default.new(false) bool hasCommandsResult, int? channelId, @Default.new(false) bool isFlespi, String? flespiId, @Default.new(false) bool hasAck, @Default.new('') String ackTopicFormat, @Default.new(false) bool isImported, @Default.new([]) List<CredentialFieldInput> requiredFields, @Default.new(false) bool canFota, String? host, int? port, String? mqttTopic, required AvatarInput dynamicIcon, String? cycleId, @Default.new(false) bool hasModbus, @Default.new([]) List<String> modbusPorts, @Default.new(false) bool requiresFlespiToken, @Default.new([]) List<FlespiAclInput> flespiAcl, WebhookStructureInput? webhookStructure, @Default.new(false) bool requiresExternalAccount, @Default.new(false) bool requiresStructure, @Default.new([]) List<CommandDefinitionInput> commandsStructure, @Default.new([]) List<ConfigGroupingInput> configStructure, @Default.new(false) bool confiotCapable, String? peripheralIdentifier, Map<String, dynamic>? peripheralParserSpec})
factory
InboundProtocolInput.fromJson(Map<String, dynamic> json)
factory

Properties

ackTopicFormat String
ackTopicFormat Ack topic format. Only used for Flespi MQTT protocols.
getter/setter pairinherited
canFota bool
canFota Boolean that indicates if the protocol can be updated with FOTA (Firmware over the air).
getter/setter pairinherited
categoriesIds List<String>
categoriesIds ID of all categories assigned
getter/setter pairinherited
channelId int?
channelId MQTT Channel ID. Only used for realtime protocols. GOLDEN M INTERNAL ONLY
getter/setter pairinherited
color Color
color Indicates the color assigned to the protocol
getter/setter pairinherited
commandsStructure List<CommandDefinitionInput>
commandsStructure is the structure of the commands for the protocol.
getter/setter pairinherited
configStructure List<ConfigGroupingInput>
configStructure is the structure of the configuration for the protocol.
getter/setter pairinherited
confiotCapable bool
confiotCapable is the boolean that indicates if the protocol is capable of using the Confiot platform.
getter/setter pairinherited
copyWith → $InboundProtocolInputCopyWith<InboundProtocolInput>
Create a copy of InboundProtocolInput with the given fields replaced by the non-null parameter values.
no setterinherited
cycleId String?
cycleId is the ID of the cycle to which the field belongs.
getter/setter pairinherited
dynamicIcon AvatarInput
dynamicIcon is the icon of the protocol.
getter/setter pairinherited
flespiAcl List<FlespiAclInput>
flespiAcl refers to the ACL for the token generation.
getter/setter pairinherited
flespiId String?
flespiId Flespi ID. Only used for Flespi protocols.
getter/setter pairinherited
hasAck bool
hasAck Boolean that indicates if the protocol has ACK support.
getter/setter pairinherited
hasCommandsResult bool
hasCommandsResult Boolean that indicates if the protocol has commands.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hasModbus bool
hasModbus is the boolean that indicates if the protocol has support for Modbus.
getter/setter pairinherited
hasNativeCommands bool
hasNativeCommands Boolean that indicates if the protocol has commands though the native comm channel.
getter/setter pairinherited
hasSmsCommands bool
hasSmsCommands Boolean that indicates if the protocol has commands though SMS.
getter/setter pairinherited
host String?
host is the host of the server, means the IP or domain (or subdomain) of the server to send or receive the information
getter/setter pairinherited
id String?
id ID of the protocol entity. This ID is unique.
getter/setter pairinherited
isEnabled bool
isEnabled Boolean that indicates if the protocol is enabled.
getter/setter pairinherited
isFlespi bool
isFlespi Boolean that indicates if the protocol is from Flespi.
getter/setter pairinherited
isImported bool
isImported Boolean that indicates if the devices from this protocol are imported from external.
getter/setter pairinherited
modbusPorts List<String>
modbusPorts is the list of Modbus ports that the protocol has.
getter/setter pairinherited
mqttTopic String?
mqttTopic is the MQTT topic to send or receive the information
getter/setter pairinherited
name String
name Name of the protocol.
getter/setter pairinherited
operationMode OperationMode
operationMode Indicates the operation mode of the protocol.
getter/setter pairinherited
peripheralIdentifier String?
peripheralIdentifier is the identifier of the peripheral device.
getter/setter pairinherited
peripheralParserSpec Map<String, dynamic>?
peripheralParserSpec is the parser specification for the peripheral device.
getter/setter pairinherited
port int?
port is the port of the server, means the port of the server to send or receive the information 0 means in API and backend services "ignore this field"
getter/setter pairinherited
requiredFields List<CredentialFieldInput>
requiredFields Required configuration fields.
getter/setter pairinherited
requiresExternalAccount bool
requiresExternalAccount indicates if the protocol requires an external account to work.
getter/setter pairinherited
requiresFlespiToken bool
requiresFlespiToken indicates if the protocol requires a Flespi token to work.
getter/setter pairinherited
requiresStructure bool
requiresStructure indicates if the protocol requires a structure to work.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webhookStructure WebhookStructureInput?
webhookStructure defines the specific methods required to handle a complete webhook operation.
getter/setter pairinherited

Methods

map<TResult extends Object?>(TResult $default(_InboundProtocolInput value)) → TResult

Available on InboundProtocolInput, provided by the InboundProtocolInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_InboundProtocolInput value)?) → TResult?

Available on InboundProtocolInput, provided by the InboundProtocolInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_InboundProtocolInput value)?, {required TResult orElse()}) → TResult

Available on InboundProtocolInput, provided by the InboundProtocolInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? id, String name, Color color, bool isEnabled, List<String> categoriesIds, OperationMode operationMode, bool hasNativeCommands, bool hasSmsCommands, bool hasCommandsResult, int? channelId, bool isFlespi, String? flespiId, bool hasAck, String ackTopicFormat, bool isImported, List<CredentialFieldInput> requiredFields, bool canFota, String? host, int? port, String? mqttTopic, AvatarInput dynamicIcon, String? cycleId, bool hasModbus, List<String> modbusPorts, bool requiresFlespiToken, List<FlespiAclInput> flespiAcl, WebhookStructureInput? webhookStructure, bool requiresExternalAccount, bool requiresStructure, List<CommandDefinitionInput> commandsStructure, List<ConfigGroupingInput> configStructure, bool confiotCapable, String? peripheralIdentifier, Map<String, dynamic>? peripheralParserSpec)?, {required TResult orElse()}) → TResult

Available on InboundProtocolInput, provided by the InboundProtocolInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this InboundProtocolInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? id, String name, Color color, bool isEnabled, List<String> categoriesIds, OperationMode operationMode, bool hasNativeCommands, bool hasSmsCommands, bool hasCommandsResult, int? channelId, bool isFlespi, String? flespiId, bool hasAck, String ackTopicFormat, bool isImported, List<CredentialFieldInput> requiredFields, bool canFota, String? host, int? port, String? mqttTopic, AvatarInput dynamicIcon, String? cycleId, bool hasModbus, List<String> modbusPorts, bool requiresFlespiToken, List<FlespiAclInput> flespiAcl, WebhookStructureInput? webhookStructure, bool requiresExternalAccount, bool requiresStructure, List<CommandDefinitionInput> commandsStructure, List<ConfigGroupingInput> configStructure, bool confiotCapable, String? peripheralIdentifier, Map<String, dynamic>? peripheralParserSpec)) → TResult

Available on InboundProtocolInput, provided by the InboundProtocolInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? id, String name, Color color, bool isEnabled, List<String> categoriesIds, OperationMode operationMode, bool hasNativeCommands, bool hasSmsCommands, bool hasCommandsResult, int? channelId, bool isFlespi, String? flespiId, bool hasAck, String ackTopicFormat, bool isImported, List<CredentialFieldInput> requiredFields, bool canFota, String? host, int? port, String? mqttTopic, AvatarInput dynamicIcon, String? cycleId, bool hasModbus, List<String> modbusPorts, bool requiresFlespiToken, List<FlespiAclInput> flespiAcl, WebhookStructureInput? webhookStructure, bool requiresExternalAccount, bool requiresStructure, List<CommandDefinitionInput> commandsStructure, List<ConfigGroupingInput> configStructure, bool confiotCapable, String? peripheralIdentifier, Map<String, dynamic>? peripheralParserSpec)?) → TResult?

Available on InboundProtocolInput, provided by the InboundProtocolInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited