InstanceStatus enum
InstanceStatus is the status of the instance
Only used when the platform is AppPlatform.web
Values
- pending → const InstanceStatus
-
API Reference: PENDING Definition: Pending Sequence: 1
- sslWaiting → const InstanceStatus
-
API Reference: SSL_WAITING Definition: Waiting for SSL Certificate Sequence: 2
- sslDnsCreation → const InstanceStatus
-
API Reference: SSL_DNS_CREATION Definition: Creating DNS Record for SSL Certificate Sequence: 3 Note: This stage is only for non-customized apps
- sslGeneration → const InstanceStatus
-
API Reference: SSL_GENERATION Definition: Generating SSL Certificate Sequence: 4
- cloudfrontGeneration → const InstanceStatus
-
API Reference: CLOUDFRONT_GENERATION Definition: Generating Distribution Sequence: 5
- cloudfrontDnsCreation → const InstanceStatus
-
API Reference: CLOUDFRONT_DNS_CREATION Definition: Creating DNS Record for CloudFront Sequence: 6 Note: This stage is only for non-customized apps
- waiting → const InstanceStatus
-
API Reference: WAITING Definition: Waiting confirmation of the provider Sequence: 7
- ready → const InstanceStatus
-
API Reference: READY Definition: Ready Sequence: 8
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
String json) → InstanceStatus
Constants
-
values
→ const List<
InstanceStatus> - A constant List of the values in this enum, in order of their declaration.