LinkedAssetToCheckpointId class abstract

LinkedAssetToCheckpointId Presence in geofence ID linked

FIELDS

itemId ID

entity LinkedAssetEntity

Available extensions
Annotations
  • @freezed

Constructors

LinkedAssetToCheckpointId({required String itemId, @LinkedAssetEntityConverter() required LinkedAssetEntity entity})
const
factory
LinkedAssetToCheckpointId.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $LinkedAssetToCheckpointIdCopyWith<LinkedAssetToCheckpointId>
Create a copy of LinkedAssetToCheckpointId with the given fields replaced by the non-null parameter values.
no setterinherited
entity LinkedAssetEntity
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
itemId String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_LinkedAssetToCheckpointId value)) → TResult

Available on LinkedAssetToCheckpointId, provided by the LinkedAssetToCheckpointIdPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_LinkedAssetToCheckpointId value)?) → TResult?

Available on LinkedAssetToCheckpointId, provided by the LinkedAssetToCheckpointIdPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_LinkedAssetToCheckpointId value)?, {required TResult orElse()}) → TResult

Available on LinkedAssetToCheckpointId, provided by the LinkedAssetToCheckpointIdPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String itemId, LinkedAssetEntity entity)?, {required TResult orElse()}) → TResult

Available on LinkedAssetToCheckpointId, provided by the LinkedAssetToCheckpointIdPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this LinkedAssetToCheckpointId to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String itemId, LinkedAssetEntity entity)) → TResult

Available on LinkedAssetToCheckpointId, provided by the LinkedAssetToCheckpointIdPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String itemId, LinkedAssetEntity entity)?) → TResult?

Available on LinkedAssetToCheckpointId, provided by the LinkedAssetToCheckpointIdPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited