MapCardMode enum

Inheritance
Available extensions

Values

lastDay → const MapCardMode
last2Days → const MapCardMode

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toJson returns the string representation of the enum value.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(String json) MapCardMode
fromJson returns the enum value from a string representation.

Constants

values → const List<MapCardMode>
A constant List of the values in this enum, in order of their declaration.