MapCardSensorsConfigurationInput class abstract

Available extensions
Annotations
  • @unfreezed

Constructors

MapCardSensorsConfigurationInput({@Default.new(true) bool enabled, @JsonKey.new(unknownEnumValue: MapSensorMode.grid) @Default.new(MapSensorMode.grid) MapSensorMode mode, @Default.new([]) List<String> values})
factory
MapCardSensorsConfigurationInput.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $MapCardSensorsConfigurationInputCopyWith<MapCardSensorsConfigurationInput>
Create a copy of MapCardSensorsConfigurationInput with the given fields replaced by the non-null parameter values.
no setterinherited
enabled bool
Indicates if the sensor segment is enabled.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
mode MapSensorMode
Represents the format of the sensor list.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String>
Indicates the sensors assigned
getter/setter pairinherited

Methods

map<TResult extends Object?>(TResult $default(_MapCardSensorsConfigurationInput value)) → TResult

Available on MapCardSensorsConfigurationInput, provided by the MapCardSensorsConfigurationInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_MapCardSensorsConfigurationInput value)?) → TResult?

Available on MapCardSensorsConfigurationInput, provided by the MapCardSensorsConfigurationInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_MapCardSensorsConfigurationInput value)?, {required TResult orElse()}) → TResult

Available on MapCardSensorsConfigurationInput, provided by the MapCardSensorsConfigurationInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool enabled, MapSensorMode mode, List<String> values)?, {required TResult orElse()}) → TResult

Available on MapCardSensorsConfigurationInput, provided by the MapCardSensorsConfigurationInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this MapCardSensorsConfigurationInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool enabled, MapSensorMode mode, List<String> values)) → TResult

Available on MapCardSensorsConfigurationInput, provided by the MapCardSensorsConfigurationInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool enabled, MapSensorMode mode, List<String> values)?) → TResult?

Available on MapCardSensorsConfigurationInput, provided by the MapCardSensorsConfigurationInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited