ModbusParameterInput class abstract

Available extensions
Annotations
  • @unfreezed

Constructors

ModbusParameterInput({@Default.new(ModbusParameterSchema.single) @ModbusParameterSchemaConverter() ModbusParameterSchema schema, String? splitEach, @Default.new('') String controllerAddress, @Default.new('') String functionCode, @Default.new('') String dataAddress, @Default.new('') String dataLength})
factory
ModbusParameterInput.fromJson(Map<String, dynamic> json)
factory

Properties

controllerAddress String
controllerAddress is the controller or slave ID of the modbus device. This value is a Hexadecimal number from 0x01 to 0xFF inclusive, the stored value shouldn't be prefixed with 0x.
getter/setter pairinherited
copyWith → $ModbusParameterInputCopyWith<ModbusParameterInput>
Create a copy of ModbusParameterInput with the given fields replaced by the non-null parameter values.
no setterinherited
dataAddress String
dataAddress is the data address of the modbus device. This value is a Hexadecimal number from 0x0000 to 0xFFFF inclusive, the stored value shouldn't be prefixed with 0x.
getter/setter pairinherited
dataLength String
dataLength is the data length of the modbus device. This value is a Hexadecimal number from 0x0001 to 0xFFFF inclusive, the stored value shouldn't be prefixed with 0x.
getter/setter pairinherited
functionCode String
functionCode is the function code of the modbus device. This value is a Hexadecimal number from 0x01 to 0xFF inclusive, the stored value shouldn't be prefixed with 0x.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schema ModbusParameterSchema
schema represents the format of the command, it can be either single or multiple.
getter/setter pairinherited
splitEach String?
splitEach represents when the data is split into multiple parts, how many parts should be split. This value is a hexadecimal value
getter/setter pairinherited

Methods

map<TResult extends Object?>(TResult $default(_ModbusParameterInput value)) → TResult

Available on ModbusParameterInput, provided by the ModbusParameterInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ModbusParameterInput value)?) → TResult?

Available on ModbusParameterInput, provided by the ModbusParameterInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ModbusParameterInput value)?, {required TResult orElse()}) → TResult

Available on ModbusParameterInput, provided by the ModbusParameterInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(ModbusParameterSchema schema, String? splitEach, String controllerAddress, String functionCode, String dataAddress, String dataLength)?, {required TResult orElse()}) → TResult

Available on ModbusParameterInput, provided by the ModbusParameterInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ModbusParameterInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(ModbusParameterSchema schema, String? splitEach, String controllerAddress, String functionCode, String dataAddress, String dataLength)) → TResult

Available on ModbusParameterInput, provided by the ModbusParameterInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(ModbusParameterSchema schema, String? splitEach, String controllerAddress, String functionCode, String dataAddress, String dataLength)?) → TResult?

Available on ModbusParameterInput, provided by the ModbusParameterInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited