schema property

schema represents the format of the command, it can be either single or multiple.

Implementation

@ModbusParameterSchemaConverter() ModbusParameterSchema get schema;
  1. @ModbusParameterSchemaConverter()
set schema (ModbusParameterSchema value)
inherited

schema represents the format of the command, it can be either single or multiple.

Implementation

@ModbusParameterSchemaConverter() ModbusParameterSchema get schema;/// [schema] represents the format of the command, it can be either single or multiple.
@ModbusParameterSchemaConverter() set schema(ModbusParameterSchema value);