OutboundMetrics class abstract

Available extensions
Annotations
  • @freezed

Constructors

OutboundMetrics({@Default.new(0) int online, @Default.new(0) int hibernation, @Default.new(0) int offline, @Default.new(0) int totalItems, @Default.new(true) bool statsLoading})
const
factory
OutboundMetrics.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $OutboundMetricsCopyWith<OutboundMetrics>
Create a copy of OutboundMetrics with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hibernation int
hibernation is the number of devices in hibernation.
no setterinherited
offline int
offline is the number of offline devices.
no setterinherited
online int
online is the number of online devices.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statsLoading bool
statsLoading indicates if the stats are loading.
no setterinherited
totalItems int
totalItems is the total number of devices.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_OutboundMetrics value)) → TResult

Available on OutboundMetrics, provided by the OutboundMetricsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_OutboundMetrics value)?) → TResult?

Available on OutboundMetrics, provided by the OutboundMetricsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_OutboundMetrics value)?, {required TResult orElse()}) → TResult

Available on OutboundMetrics, provided by the OutboundMetricsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int online, int hibernation, int offline, int totalItems, bool statsLoading)?, {required TResult orElse()}) → TResult

Available on OutboundMetrics, provided by the OutboundMetricsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this OutboundMetrics to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int online, int hibernation, int offline, int totalItems, bool statsLoading)) → TResult

Available on OutboundMetrics, provided by the OutboundMetricsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int online, int hibernation, int offline, int totalItems, bool statsLoading)?) → TResult?

Available on OutboundMetrics, provided by the OutboundMetricsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited