ParamData class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- ParamData({dynamic value, @TimestampConverter() DateTime? updatedAt})
-
constfactory
-
ParamData.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $ParamDataCopyWith<
ParamData> -
Create a copy of ParamData
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → DateTime?
-
updatedAtis a timestamp indicating when the parameter was last updated.no setterinherited - value → dynamic
-
valuerepresents the new value of the parameter being updated.no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ParamData value)) → TResult -
Available on ParamData, provided by the ParamDataPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ParamData value)?) → TResult? -
Available on ParamData, provided by the ParamDataPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ParamData value)?, {required TResult orElse()}) → TResult -
Available on ParamData, provided by the ParamDataPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(dynamic value, DateTime? updatedAt)?, {required TResult orElse()}) → TResult -
Available on ParamData, provided by the ParamDataPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ParamData to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(dynamic value, DateTime? updatedAt)) → TResult -
Available on ParamData, provided by the ParamDataPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(dynamic value, DateTime? updatedAt)?) → TResult? -
Available on ParamData, provided by the ParamDataPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited