ReferenceCategory enum

Inheritance
Available extensions

Values

driver → const ReferenceCategory

Defines the reference as a Driver reference, generally used to identify a driver universally. Layrz API Reference: DRIVER

client → const ReferenceCategory

Defines the reference as a client reference, generally used to identify a client universally. Layrz API Reference: CLIENT

universal → const ReferenceCategory

Universal reference category, we recommend use correctly the custom fields to prevent confusion or mistakes with the reference. Layrz API Reference: UNIVERSAL

monitorist → const ReferenceCategory

!ATS Reference Defines the access to the access to monitorist module. Layrz API Reference: MONITORIST

atsMobile → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Mobile app Layrz API Reference: ATS_MOBILE

atsTank → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module tanks Layrz API Reference: ATS_TANK

atsPump → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module pumps Layrz API Reference: ATS_PUMP

atsFleet → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module fleet Layrz API Reference: ATS_FLEET

atsConvoy → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module convoy Layrz API Reference: ATS_CONVOY

atsLubrication → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module Layrz API Reference: ATS_LUBRICATION

atsTankHistory → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module tank history Layrz API Reference: ATS_TANK_HISTORY

atsEntries → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module entries history Layrz API Reference: ATS_ENTRIES,

atsPurchaseOrders → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module purchase orders Layrz API Reference: ATS_PURCHASE_ORDERS

atsLinkPurchases → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module link purchases Layrz API Reference: ATS_LINK_PURCHASES

atsDashboard360 → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module dashboard 360 Layrz API Reference: ATS_DASHBOARD_360

atsRegisterPurchases → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module register purchases Layrz API Reference: ATS_REGISTER_PURCHASES

atsUploadPurchasesXml → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module upload purchases XML Layrz API Reference: ATS_UPLOAD_PURCHASES_XML

atsExecuteExitConvoy → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module exit convoy Layrz API Reference: ATS_EXECUTE_EXIT_CONVOY

atsExits → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module exits history Layrz API Reference: ATS_EXITS

atsPumpHistory → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module pump history Layrz API Reference: ATS_PUMP_HISTORY

atsExecuteExit → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module execute exit Layrz API Reference: ATS_EXECUTE_EXIT

atsTankLevels → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module tank levels Layrz API Reference: ATS_TANK_LEVELS

atsNfcExecuteExit → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module execute NFC exits Layrz API Reference: ATS_NFC_EXECUTE_EXIT

atsSelectionManualExecuteExit → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module manual exits Layrz API Reference: ATS_SELECTION_MANUAL_EXECUTE_EXIT

atsAutomaticReception → const ReferenceCategory

!ATS Reference Defines the access to the access to the ATS Web module automatic reception Layrz API Reference: ATS_AUTOMATIC_RECEPTION

atsDriver → const ReferenceCategory

!ATS Reference Defines the access user as a driver on ATS ecosystem Layrz API Reference: ATS_DRIVER

atsTerminalOperations → const ReferenceCategory

!ATS Reference Defines the access to the ATS Web module terminal operations Layrz API Reference: ATS_TERMINAL_OPERATIONS

atsTerminalLoadingGrid → const ReferenceCategory

!ATS Reference Defines the access to the ATS Web module terminal loading grid Layrz API Reference: ATS_TERMINAL_LOADING_GRID

atsTerminalAccessControl → const ReferenceCategory

!ATS Reference Defines the access to the ATS Web module terminal access control Layrz API Reference: ATS_TERMINAL_ACCESS_CONTROL

atsTerminalYardAlerts → const ReferenceCategory

!ATS Reference Defines the access to the ATS Web module terminal yard alerts Layrz API Reference: ATS_TERMINAL_YARD_ALERTS

atsTerminalLoadFormatting → const ReferenceCategory

!ATS Reference Defines the access to the ATS Web module terminal load formatting Layrz API Reference: ATS_TERMINAL_LOAD_FORMATTING

atsTerminalStockManagement → const ReferenceCategory

!ATS Reference Defines the access to the ATS Web module terminal stock management Layrz API Reference: ATS_TERMINAL_STOCK_MANAGEMENT

atsTerminalCacl → const ReferenceCategory

!ATS Reference Defines the access to the ATS Web module terminal CACL Layrz API Reference: ATS_TERMINAL_CACL

atsTerminalEditTransport → const ReferenceCategory

!ATS Reference Defines the access to the ATS Web module terminal edit transport Layrz API Reference: ATS_TERMINAL_EDIT_TRANSPORT

atsAccessColeta → const ReferenceCategory

!ATS Reference Defines the access to the ATS Web module terminal edit transport Layrz API Reference: ATS_ACCESS_COLETA

atsPaLoadComboio → const ReferenceCategory

!ATS Reference Defines the access to the ATS Web module terminal edit transport Layrz API Reference: ATS_PA_LOAD_COMBOIO

atsSendOdometerInExecuteExits → const ReferenceCategory

!ATS Reference AllTank Systems Access to send odometer in execute exits ATS_SEND_ODOMETER_IN_EXECUTE_EXITS

atsRecalculateOperationButton → const ReferenceCategory

!ATS Reference AllTank Systems Access to the recalculate operation button ATS_RECALCULATE_OPERATION_BUTTON

atsBalsaBordo → const ReferenceCategory

!ATS Reference AllTank Systems Access to the balsa bordo module ATS_BALSA_BORDO

atsBalsaExportReceivementReportPdf → const ReferenceCategory

!ATS Reference AllTank Systems Access to export receivement report PDF ATS_BALSA_EXPORT_RECEIVEMENT_REPORT_PDF

atsExportRaftClosureReportPdf → const ReferenceCategory

!ATS Reference AllTank Systems Access to export closure report PDF ATS_EXPORT_RAFT_CLOSURE_REPORT_PDF

atsSupervisorioEditCacl → const ReferenceCategory

!ATS Reference AllTank Systems Access to the CACL edit in supervisorio module ATS_SUPERVISORIO_EDIT_CACL

atsSupervisorioRemoveCacl → const ReferenceCategory

!ATS Reference AllTank Systems Access to the CACL remove in supervisorio module ATS_SUPERVISORIO_REMOVE_CACL

atsSupervisorioExportCacl → const ReferenceCategory

!ATS Reference AllTank Systems Access to the CACL export in supervisorio module ATS_SUPERVISORIO_EXPORT_CACL

atsPreventChangesInCaclTelemetryInputs → const ReferenceCategory

!ATS Reference AllTank Systems Access to prevent changes in CACL telemetry inputs ATS_PREVENT_CHANGES_IN_CACL_TELEMETRY_INPUTS

atsGetAllTerminals → const ReferenceCategory

!ATS Reference AllTank Systems Access to get all terminals in terminal operations module Layrz API Reference: ATS_GET_ALL_TERMINALS

atsStorageReceptionAccess → const ReferenceCategory

!ATS Reference AllTank Systems Access to the storage reception module Layrz API Reference: ATS_STORAGE_RECEPTION_ACCESS

atsInvoiceSwap → const ReferenceCategory

!ATS Reference AllTank Systems Access to swap invoice in purchase order Layrz API Reference: ATS_INVOICE_SWAP

atsShowOnlyLastExit → const ReferenceCategory

!ATS Reference AllTank Systems When present on a pump asset, the history view must show only the most recent exit instead of the full list. Layrz API Reference: ATS_SHOW_ONLY_LAST_EXIT

atsSupervisorioAllowCloseRaftOperation → const ReferenceCategory

!ATS Reference AllTank Systems Access to close raft operation in supervisorio module Layrz API Reference: ATS_SUPERVISORIO_ALLOW_CLOSE_RAFT_OPERATION

mappitOperator → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit module as a operator or mappit employee Layrz API Reference: MAPPIT_OPERATOR

mappitCustomer → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit module as a customer Layrz API Reference: MAPPIT_CUSTOMER

mappitEmployee → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit module as a employee Layrz API Reference: MAPPIT_EMPLOYEE

mappitSupervisor → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit module as a supervisor Layrz API Reference: MAPPIT_SUPERVISOR

mappitSeller → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit module as a seller Layrz API Reference: MAPPIT_SELLER

mappitPermHome → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module home Layrz API Reference: MAPPIT_PERM_HOME

mappitPermGeomarketing → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module geomarketing Layrz API Reference: MAPPIT_PERM_GEOMARKETING

mappitPermTimeManagement → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module time management Layrz API Reference: MAPPIT_PERM_TIME_MANAGEMENT

mappitPermReports → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module reports Layrz API Reference: MAPPIT_PERM_REPORTS

mappitPermRoutes → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module routes Layrz API Reference: MAPPIT_PERM_ROUTES

mappitPermUsersRead → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module users read only Layrz API Reference: MAPPIT_PERM_USERS_READ

mappitPermUsersFull → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module users full Layrz API Reference: MAPPIT_PERM_USERS_FULL

mappitPermSupervisorsRead → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module supervisors read only Layrz API Reference: MAPPIT_PERM_SUPERVISORS_READ

mappitPermSupervisorsFull → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module supervisors full Layrz API Reference: MAPPIT_PERM_SUPERVISORS_FULL

mappitPermSellers → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module sellers Layrz API Reference: MAPPIT_PERM_SELLERS

mappitPermOperatorsRead → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module operators read only Layrz API Reference: MAPPIT_PERM_OPERATORS_READ

mappitPermOperatorsFull → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module operators full Layrz API Reference: MAPPIT_PERM_OPERATORS_FULL

mappitPermGeofencesCfWrite → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module customers read only Layrz API Reference: MAPPIT_PERM_GEOFENCES_CF_WRITE

mappitPermPolygonsRead → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module customers full Layrz API Reference: MAPPIT_PERM_POLYGONS_READ

mappitPermPolygonsFull → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module customers full Layrz API Reference: MAPPIT_PERM_POLYGONS_FULL

mappitPermProfilesRead → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module customers read only Layrz API Reference: MAPPIT_PERM_PROFILES_READ

mappitPermProfilesFull → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module customers full Layrz API Reference: MAPPIT_PERM_PROFILES_FULL

mappitPermFreeDaysRead → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module customers read only Layrz API Reference: MAPPIT_PERM_FREEDAYS_READ

mappitPermFreeDaysFull → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module customers full Layrz API Reference: MAPPIT_PERM_FREEDAYS_FULL

mappitPermTagsRead → const ReferenceCategory

!Mappit Reference Defines the access to the Mappit Analytics module customers read only Layrz API Reference: MAPPIT_PERM_TAGS_READ

tenvioDispatcher → const ReferenceCategory

!Tenvio Reference Defines the user as a dispatcher on Tenvio ecosystem Layrz API Reference: TENVIO_DISPATCHER

tenvioOperator → const ReferenceCategory

!Tenvio Reference Defines the user as a operator on Tenvio ecosystem Layrz API Reference: TENVIO_OPERATOR

tenvioDriver → const ReferenceCategory

!Tenvio Reference Defines the user as a driver on Tenvio ecosystem Layrz API Reference: TENVIO_DRIVER

tenvioClient → const ReferenceCategory

!Tenvio Reference Defines the user as a client on Tenvio ecosystem Layrz API Reference: TENVIO_CLIENT

tenvioAdmin → const ReferenceCategory

!Tenvio Reference Defines the user as a admin on Tenvio ecosystem Layrz API Reference: TENVIO_ADMIN

sdmAdmin → const ReferenceCategory

!SDM Reference Defines the user as a admin on SDM ecosystem Layrz API Reference: SDM_ADMIN

sdmSupervisor → const ReferenceCategory

!SDM Reference Defines the user as a supervisor on SDM ecosystem Layrz API Reference: SDM_SUPERVISOR

sdmOperator → const ReferenceCategory

!SDM Reference Defines the user as a operator on SDM ecosystem Layrz API Reference: SDM_OPERATOR

sdmGuest → const ReferenceCategory

!SDM Reference Defines the user as a guest on SDM ecosystem Layrz API Reference: SDM_GUEST

unknown → const ReferenceCategory

Defines a value that is not known or not applicable. Layrz API Reference: UNKNOWN

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
translationKey String
translationKey returns the translation key for the enum value. This translation key is defined by Golden M Team and should be used with the Layrz Translation System
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toJson returns the string representation of the enum value.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(String json) ReferenceCategory
fromJson returns the enum value from a string representation.

Constants

values → const List<ReferenceCategory>
A constant List of the values in this enum, in order of their declaration.