TankMeasurementInput class abstract

A model class representing a tank measurements input.

Available extensions
Annotations
  • @unfreezed

Constructors

TankMeasurementInput({@Default.new('') String tankSlug, @Default.new('') String fuelSubtype, @Default.new(0.0) double height, @Deprecated('Use sampleTemperature instead') double? temperature, @Default.new(0.0) double volume, @Default.new(0.0) double fuelDensity, double? sampleTemperature, double? tankTemperature})
factory
TankMeasurementInput.fromJson(Map<String, dynamic> json)
Creates a new TankMeasurementInput instance from a JSON map.
factory

Properties

copyWith → $TankMeasurementInputCopyWith<TankMeasurementInput>
Create a copy of TankMeasurementInput with the given fields replaced by the non-null parameter values.
no setterinherited
fuelDensity double
The fuelDensity parameter is the fuel density of the tank measurement.
getter/setter pairinherited
fuelSubtype String
The fuelSubtype parameter is the fuel subtype (ANP code).
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
height double
The height parameter is the height of the tank measurement.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleTemperature double?
The sampleTemperature parameter is the sample temperature of the tank measurement.
getter/setter pairinherited
tankSlug String
The tankSlug parameter is the tank slug.
getter/setter pairinherited
tankTemperature double?
The tankTemperature parameter is the tank temperature of the tank measurement.
getter/setter pairinherited
temperature double?
The temperature parameter is the temperature of the tank measurement.
getter/setter pairinherited
volume double
The volume parameter is the volume of the tank measurement.
getter/setter pairinherited

Methods

map<TResult extends Object?>(TResult $default(_TankMeasurementInput value)) → TResult

Available on TankMeasurementInput, provided by the TankMeasurementInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_TankMeasurementInput value)?) → TResult?

Available on TankMeasurementInput, provided by the TankMeasurementInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_TankMeasurementInput value)?, {required TResult orElse()}) → TResult

Available on TankMeasurementInput, provided by the TankMeasurementInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String tankSlug, String fuelSubtype, double height, double? temperature, double volume, double fuelDensity, double? sampleTemperature, double? tankTemperature)?, {required TResult orElse()}) → TResult

Available on TankMeasurementInput, provided by the TankMeasurementInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this TankMeasurementInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String tankSlug, String fuelSubtype, double height, double? temperature, double volume, double fuelDensity, double? sampleTemperature, double? tankTemperature)) → TResult

Available on TankMeasurementInput, provided by the TankMeasurementInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String tankSlug, String fuelSubtype, double height, double? temperature, double volume, double fuelDensity, double? sampleTemperature, double? tankTemperature)?) → TResult?

Available on TankMeasurementInput, provided by the TankMeasurementInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited