TenvioMatrixItemPatterns extension

Adds pattern-matching-related methods to TenvioMatrixItem.

on

Methods

map<TResult extends Object?>(TResult $default(_TenvioMatrixItem value)) → TResult

Available on TenvioMatrixItem, provided by the TenvioMatrixItemPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_TenvioMatrixItem value)?) → TResult?

Available on TenvioMatrixItem, provided by the TenvioMatrixItemPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_TenvioMatrixItem value)?, {required TResult orElse()}) → TResult

Available on TenvioMatrixItem, provided by the TenvioMatrixItemPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, String name, String? image, String code, String? qrCode, double? weight, double? width, double? height, List<TenvioCustomProperty>? customProperties, DateTime? createdAt, DateTime? updatedAt, List<TenvioItem>? items)?, {required TResult orElse()}) → TResult

Available on TenvioMatrixItem, provided by the TenvioMatrixItemPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String id, String name, String? image, String code, String? qrCode, double? weight, double? width, double? height, List<TenvioCustomProperty>? customProperties, DateTime? createdAt, DateTime? updatedAt, List<TenvioItem>? items)) → TResult

Available on TenvioMatrixItem, provided by the TenvioMatrixItemPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, String name, String? image, String code, String? qrCode, double? weight, double? width, double? height, List<TenvioCustomProperty>? customProperties, DateTime? createdAt, DateTime? updatedAt, List<TenvioItem>? items)?) → TResult?

Available on TenvioMatrixItem, provided by the TenvioMatrixItemPatterns extension

A variant of when that fallback to returning null