BillingPlanInput class abstract
- Available extensions
- Annotations
-
- @unfreezed
Constructors
-
BillingPlanInput({String? id, @Default.new(0.0) double reconnectionPercent, @Default.new(0) int reconnectionMaximum, @Default.new(0) int reconnectionIncidents, @Default.new(0) int maxAssets, @Default.new(0) int maxDevices, @Default.new(0) int maxUsers, @Default.new(0) int maxOutboundServices, @Default.new(0) int maxFunctions, @Default.new(0) int maxApps, @Default.new([]) List<
String> allowedAppsIds, @Default.new([]) List<String> allowedAlgorithmsIds, @Default.new([]) List<String> allowedInboundProtocolsIds, @Default.new([]) List<String> allowedOutboundProtocolsIds, @Default.new([]) List<String> allowedVisionProtocolsIds, @Default.new([]) List<String> allowedExchangeProtocolsIds, @Default.new(false) bool aiEnabled}) -
factory
-
BillingPlanInput.fromJson(Map<
String, dynamic> json) -
factory
Properties
- aiEnabled ↔ bool
-
aiEnabledis a boolean indicating if AI is enabled for the billing plan.getter/setter pairinherited -
allowedAlgorithmsIds
↔ List<
String> -
allowedAlgorithmsIdsis the list of allowed algorithm IDs for the billing plan.getter/setter pairinherited -
allowedAppsIds
↔ List<
String> -
allowedAppsIdsis the list of allowed app IDs for the billing plan.getter/setter pairinherited -
allowedExchangeProtocolsIds
↔ List<
String> -
allowedExchangeProtocolsIdsis the list of allowed exchange protocol IDs for the billing plan.getter/setter pairinherited -
allowedInboundProtocolsIds
↔ List<
String> -
allowedInboundProtocolsIdsis the list of allowed inbound protocol IDs for the billing plan.getter/setter pairinherited -
allowedOutboundProtocolsIds
↔ List<
String> -
allowedOutboundProtocolsIdsis the list of allowed outbound protocol IDs for the billing plan.getter/setter pairinherited -
allowedVisionProtocolsIds
↔ List<
String> -
allowedVisionProtocolsIdsis the list of allowed vision protocol IDs for the billing plan.getter/setter pairinherited -
copyWith
→ $BillingPlanInputCopyWith<
BillingPlanInput> -
Create a copy of BillingPlanInput
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
idis the unique identifier for the billing plan.getter/setter pairinherited - maxApps ↔ int
-
maxAppsis the maximum number of apps allowed for the billing plan.getter/setter pairinherited - maxAssets ↔ int
-
maxAssetsis the maximum number of assets allowed for the billing plan.getter/setter pairinherited - maxDevices ↔ int
-
maxDevicesis the maximum number of devices allowed for the billing plan.getter/setter pairinherited - maxFunctions ↔ int
-
maxFunctionsis the maximum number of functions allowed for the billing plan.getter/setter pairinherited - maxOutboundServices ↔ int
-
maxOutboundServicesis the maximum number of outbound services allowed for the billing plan.getter/setter pairinherited - maxUsers ↔ int
-
maxUsersis the maximum number of users allowed for the billing plan.getter/setter pairinherited - reconnectionIncidents ↔ int
-
reconnectionIncidentsis the number of reconnection incidents allowed for the billing plan.getter/setter pairinherited - reconnectionMaximum ↔ int
-
reconnectionMaximumis the maximum number of reconnections allowed for the billing plan.getter/setter pairinherited - reconnectionPercent ↔ double
-
reconnectionPercentis the percentage of reconnections allowed for the billing plan.getter/setter pairinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_BillingPlanInput value)) → TResult -
Available on BillingPlanInput, provided by the BillingPlanInputPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_BillingPlanInput value)?) → TResult? -
Available on BillingPlanInput, provided by the BillingPlanInputPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_BillingPlanInput value)?, {required TResult orElse()}) → TResult -
Available on BillingPlanInput, provided by the BillingPlanInputPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? id, double reconnectionPercent, int reconnectionMaximum, int reconnectionIncidents, int maxAssets, int maxDevices, int maxUsers, int maxOutboundServices, int maxFunctions, int maxApps, List< String> allowedAppsIds, List<String> allowedAlgorithmsIds, List<String> allowedInboundProtocolsIds, List<String> allowedOutboundProtocolsIds, List<String> allowedVisionProtocolsIds, List<String> allowedExchangeProtocolsIds, bool aiEnabled)?, {required TResult orElse()}) → TResult -
Available on BillingPlanInput, provided by the BillingPlanInputPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this BillingPlanInput to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? id, double reconnectionPercent, int reconnectionMaximum, int reconnectionIncidents, int maxAssets, int maxDevices, int maxUsers, int maxOutboundServices, int maxFunctions, int maxApps, List< String> allowedAppsIds, List<String> allowedAlgorithmsIds, List<String> allowedInboundProtocolsIds, List<String> allowedOutboundProtocolsIds, List<String> allowedVisionProtocolsIds, List<String> allowedExchangeProtocolsIds, bool aiEnabled)) → TResult -
Available on BillingPlanInput, provided by the BillingPlanInputPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? id, double reconnectionPercent, int reconnectionMaximum, int reconnectionIncidents, int maxAssets, int maxDevices, int maxUsers, int maxOutboundServices, int maxFunctions, int maxApps, List< String> allowedAppsIds, List<String> allowedAlgorithmsIds, List<String> allowedInboundProtocolsIds, List<String> allowedOutboundProtocolsIds, List<String> allowedVisionProtocolsIds, List<String> allowedExchangeProtocolsIds, bool aiEnabled)?) → TResult? -
Available on BillingPlanInput, provided by the BillingPlanInputPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited