maxApps property
maxApps is the maximum number of apps allowed for the billing plan.
Implementation
set maxFunctions(int value);/// [maxApps] is the maximum number of apps allowed for the billing plan.
int get maxApps;
maxApps is the maximum number of apps allowed for the billing plan.
Implementation
int get maxApps;/// [maxApps] is the maximum number of apps allowed for the billing plan.
set maxApps(int value);