maxDevices property
maxDevices is the maximum number of devices allowed for the billing plan.
Implementation
set maxAssets(int value);/// [maxDevices] is the maximum number of devices allowed for the billing plan.
int get maxDevices;
maxDevices is the maximum number of devices allowed for the billing plan.
Implementation
int get maxDevices;/// [maxDevices] is the maximum number of devices allowed for the billing plan.
set maxDevices(int value);