maxUsers property

int get maxUsers
inherited

maxUsers is the maximum number of users allowed for the billing plan.

Implementation

set maxDevices(int value);/// [maxUsers] is the maximum number of users allowed for the billing plan.
int get maxUsers;
set maxUsers (int value)
inherited

maxUsers is the maximum number of users allowed for the billing plan.

Implementation

int get maxUsers;/// [maxUsers] is the maximum number of users allowed for the billing plan.
set maxUsers(int value);