CaclEntity class abstract
A model class representing a cacl entity.
- Available extensions
- Annotations
-
- @freezed
Constructors
- CaclEntity({String? id, String? assetId, Asset? asset, String? transportAssetId, Asset? transportAsset, String? transportUserId, User? transportUser, String? caclNumber, @JsonKey.new(unknownEnumValue: CaclCategory.load) CaclCategory? category, String? product, String? clientAssetId, Asset? clientAsset, String? origin, String? tankNumber, String? transport, CaclEquipmentEntity? equipments, MeasurementsEntity? measurements, ResultsEntity? results, CaclMeasurementOutput? measurer01, CaclMeasurementOutput? measurer02, VolumeMovedEntity? volumeMoved, String? observations, @TimestampOrNullConverter() DateTime? startedAt, @TimestampOrNullConverter() DateTime? finishedAt, @TimestampOrNullConverter() DateTime? createdAt, String? createdByUserId, User? createdByUser, String? operationId, AtsOperation? operation, @TimestampOrNullConverter() DateTime? localDateStart, @TimestampOrNullConverter() DateTime? localDateEnd, double? lossPercentage, bool? isCombine, Asset? tankAsset, @TimestampOrNullConverter() DateTime? signedAt, CaclTFBDetails? tfbDetails})
-
Creates a new CaclEntity instance.
factory
-
CaclEntity.fromJson(Map<
String, dynamic> json) -
Creates a new CaclEntity instance from a JSON map.
factory
Properties
- asset → Asset?
-
The
assetparameter is the asset of the cacl entity.no setterinherited - assetId → String?
-
The
assetIdparameter is the assetId of the cacl entity.no setterinherited - caclNumber → String?
-
The
caclNumberparameter is the caclNumber of the cacl entity.no setterinherited - category → CaclCategory?
-
The
categoryparameter is the category of the cacl entity.no setterinherited - clientAsset → Asset?
-
The
clientAssetparameter is the clientAsset of the cacl entity.no setterinherited - clientAssetId → String?
-
The
clientAssetIdparameter is the clientAssetId of the cacl entity.no setterinherited -
copyWith
→ $CaclEntityCopyWith<
CaclEntity> -
Create a copy of CaclEntity
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime?
-
The
createdAtparameter is the createdAt of the cacl entity.no setterinherited - createdByUser → User?
-
The
createdByUserparameter is the user who created the cacl entity.no setterinherited - createdByUserId → String?
-
The
createdByUserIdparameter is the id of the user who created the cacl entity.no setterinherited - equipments → CaclEquipmentEntity?
-
The
equipmentsparameter is the equipments of the cacl entity.no setterinherited - finishedAt → DateTime?
-
The
finishedAtparameter is the finishedAt of the cacl entity.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
The
idparameter is the id of the cacl entity.no setterinherited - isCombine → bool?
-
isCombineindicates if the cacl is a combined form.no setterinherited - localDateEnd → DateTime?
-
localDateEndis the local date end of the cacl entity.no setterinherited - localDateStart → DateTime?
-
localDateStartis the local date start of the cacl entity.no setterinherited - lossPercentage → double?
-
lossPercentageis the loss percentage of the cacl entity.no setterinherited - measurements → MeasurementsEntity?
-
The
measurementsparameter is the measurements of the cacl entity.no setterinherited - measurer01 → CaclMeasurementOutput?
-
The
measurer01parameter is the measurer01 of the cacl entity.no setterinherited - measurer02 → CaclMeasurementOutput?
-
The
measurer02parameter is the measurer02 of the cacl entity.no setterinherited - observations → String?
-
The
observationsparameter is the observations of the cacl entity.no setterinherited - operation → AtsOperation?
-
The
operationparameter is the operation of the cacl entity.no setterinherited - operationId → String?
-
The
operationIdparameter is the operationId of the cacl entity.no setterinherited - origin → String?
-
The
originparameter is the origin of the cacl entity.no setterinherited - product → String?
-
The
productparameter is the product of the cacl entity.no setterinherited - results → ResultsEntity?
-
The
resultsparameter is the results of the cacl entity.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signedAt → DateTime?
-
The
signedAtparameter is the signedAt of the cacl entity.no setterinherited - startedAt → DateTime?
-
The
startedAtparameter is the startedAt of the cacl entity.no setterinherited - tankAsset → Asset?
-
The
tankAssetparameter is the tankAsset of the cacl entity.no setterinherited - tankNumber → String?
-
The
tankNumberparameter is the tankNumber of the cacl entity.no setterinherited - tfbDetails → CaclTFBDetails?
-
The
tfbDetailsparameter is the tfbDetails of the cacl entity.no setterinherited - transport → String?
-
The
transportparameter is the transport of the cacl entity.no setterinherited - transportAsset → Asset?
-
The
transportAssetparameter is the transportAsset of the cacl entity.no setterinherited - transportAssetId → String?
-
The
transportAssetIdparameter is the transportAssetId of the cacl entity.no setterinherited - transportUser → User?
-
The
transportUserparameter is the transportUser of the cacl entity.no setterinherited - transportUserId → String?
-
The
transportUserIdparameter is the transportUserId of the cacl entity.no setterinherited - volumeMoved → VolumeMovedEntity?
-
The
volumeMovedparameter is the volumeMoved of the cacl entity.no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_CaclEntity value)) → TResult -
Available on CaclEntity, provided by the CaclEntityPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_CaclEntity value)?) → TResult? -
Available on CaclEntity, provided by the CaclEntityPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_CaclEntity value)?, {required TResult orElse()}) → TResult -
Available on CaclEntity, provided by the CaclEntityPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? id, String? assetId, Asset? asset, String? transportAssetId, Asset? transportAsset, String? transportUserId, User? transportUser, String? caclNumber, CaclCategory? category, String? product, String? clientAssetId, Asset? clientAsset, String? origin, String? tankNumber, String? transport, CaclEquipmentEntity? equipments, MeasurementsEntity? measurements, ResultsEntity? results, CaclMeasurementOutput? measurer01, CaclMeasurementOutput? measurer02, VolumeMovedEntity? volumeMoved, String? observations, DateTime? startedAt, DateTime? finishedAt, DateTime? createdAt, String? createdByUserId, User? createdByUser, String? operationId, AtsOperation? operation, DateTime? localDateStart, DateTime? localDateEnd, double? lossPercentage, bool? isCombine, Asset? tankAsset, DateTime? signedAt, CaclTFBDetails? tfbDetails)?, {required TResult orElse()}) → TResult -
Available on CaclEntity, provided by the CaclEntityPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this CaclEntity to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? id, String? assetId, Asset? asset, String? transportAssetId, Asset? transportAsset, String? transportUserId, User? transportUser, String? caclNumber, CaclCategory? category, String? product, String? clientAssetId, Asset? clientAsset, String? origin, String? tankNumber, String? transport, CaclEquipmentEntity? equipments, MeasurementsEntity? measurements, ResultsEntity? results, CaclMeasurementOutput? measurer01, CaclMeasurementOutput? measurer02, VolumeMovedEntity? volumeMoved, String? observations, DateTime? startedAt, DateTime? finishedAt, DateTime? createdAt, String? createdByUserId, User? createdByUser, String? operationId, AtsOperation? operation, DateTime? localDateStart, DateTime? localDateEnd, double? lossPercentage, bool? isCombine, Asset? tankAsset, DateTime? signedAt, CaclTFBDetails? tfbDetails)) → TResult -
Available on CaclEntity, provided by the CaclEntityPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? id, String? assetId, Asset? asset, String? transportAssetId, Asset? transportAsset, String? transportUserId, User? transportUser, String? caclNumber, CaclCategory? category, String? product, String? clientAssetId, Asset? clientAsset, String? origin, String? tankNumber, String? transport, CaclEquipmentEntity? equipments, MeasurementsEntity? measurements, ResultsEntity? results, CaclMeasurementOutput? measurer01, CaclMeasurementOutput? measurer02, VolumeMovedEntity? volumeMoved, String? observations, DateTime? startedAt, DateTime? finishedAt, DateTime? createdAt, String? createdByUserId, User? createdByUser, String? operationId, AtsOperation? operation, DateTime? localDateStart, DateTime? localDateEnd, double? lossPercentage, bool? isCombine, Asset? tankAsset, DateTime? signedAt, CaclTFBDetails? tfbDetails)?) → TResult? -
Available on CaclEntity, provided by the CaclEntityPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited