CaclInput class sealed
A model class representing a cacl input.
- Available extensions
- Annotations
-
- @unfreezed
Constructors
- CaclInput({String? id, String? assetId, String? transportAssetId, String? transportUserId, String? caclNumber, @JsonKey.new(unknownEnumValue: CaclCategory.load) CaclCategory? category, String? product, String? clientAssetId, String? tankNumber, String? transport, CaclEquipmentInput? equipments, MeasurementsInput? measurements, ResultsInput? results, CaclMeasurement? measurer01, CaclMeasurement? measurer02, VolumeMovedInput? volumeMoved, String? observations, @TimestampOrNullConverter() DateTime? startedAt, @TimestampOrNullConverter() DateTime? finishedAt, String? operationId, @TimestampOrNullConverter() DateTime? localDateStart, @TimestampOrNullConverter() DateTime? localDateEnd, CaclTFBDetailsInput? tfbDetails})
-
factory
-
CaclInput.fromJson(Map<
String, dynamic> json) -
Creates a new CaclInput instance from a JSON map.
factory
Properties
- assetId ↔ String?
-
The
assetIdparameter is the assetId of the cacl input.getter/setter pairinherited - caclNumber ↔ String?
-
The
caclNumberparameter is the caclNumber of the cacl input.getter/setter pairinherited - category ↔ CaclCategory?
-
The
categoryparameter is the category of the cacl input.getter/setter pairinherited - clientAssetId ↔ String?
-
The
clientAssetIdparameter is the clientAssetId of the cacl input.getter/setter pairinherited -
copyWith
→ $CaclInputCopyWith<
CaclInput> -
Create a copy of CaclInput
with the given fields replaced by the non-null parameter values.
no setterinherited
- equipments ↔ CaclEquipmentInput?
-
The
equipmentsparameter is the equipments of the cacl input.getter/setter pairinherited - finishedAt ↔ DateTime?
-
The
finishedAtparameter is the finishedAt of the cacl input.getter/setter pairinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The
idparameter is the id of the cacl input.getter/setter pairinherited - localDateEnd ↔ DateTime?
-
localDateEndis the local date end of the cacl input.getter/setter pairinherited - localDateStart ↔ DateTime?
-
localDateStartis the local date start of the cacl input.getter/setter pairinherited - measurements ↔ MeasurementsInput?
-
The
measurementsparameter is the measurements of the cacl input.getter/setter pairinherited - measurer01 ↔ CaclMeasurement?
-
The
measurer01parameter is the measurer01 of the cacl input.getter/setter pairinherited - measurer02 ↔ CaclMeasurement?
-
The
measurer02parameter is the measurer02 of the cacl input.getter/setter pairinherited - observations ↔ String?
-
The
observationsparameter is the observations of the cacl input.getter/setter pairinherited - operationId ↔ String?
-
The
operationIdparameter is the operationId of the cacl entity.getter/setter pairinherited - product ↔ String?
-
The
productparameter is the product of the cacl input.getter/setter pairinherited - results ↔ ResultsInput?
-
The
resultsparameter is the results of the cacl input.getter/setter pairinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedAt ↔ DateTime?
-
The
startedAtparameter is the startedAt of the cacl input.getter/setter pairinherited - tankNumber ↔ String?
-
The
tankNumberparameter is the tankNumber of the cacl input.getter/setter pairinherited - tfbDetails ↔ CaclTFBDetailsInput?
-
The
tfbDetailsparameter is the tfbDetails of the cacl input.getter/setter pairinherited - transport ↔ String?
-
The
transportparameter is the transport of the cacl input.getter/setter pairinherited - transportAssetId ↔ String?
-
The
transportAssetIdparameter is the transportAssetId of the cacl input.getter/setter pairinherited - transportUserId ↔ String?
-
The
transportUserIdparameter is the transportUserId of the cacl input.getter/setter pairinherited - volumeMoved ↔ VolumeMovedInput?
-
The
volumeMovedparameter is the volumeMoved of the cacl input.getter/setter pairinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_CaclInput value)) → TResult -
Available on CaclInput, provided by the CaclInputPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_CaclInput value)?) → TResult? -
Available on CaclInput, provided by the CaclInputPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_CaclInput value)?, {required TResult orElse()}) → TResult -
Available on CaclInput, provided by the CaclInputPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? id, String? assetId, String? transportAssetId, String? transportUserId, String? caclNumber, CaclCategory? category, String? product, String? clientAssetId, String? tankNumber, String? transport, CaclEquipmentInput? equipments, MeasurementsInput? measurements, ResultsInput? results, CaclMeasurement? measurer01, CaclMeasurement? measurer02, VolumeMovedInput? volumeMoved, String? observations, DateTime? startedAt, DateTime? finishedAt, String? operationId, DateTime? localDateStart, DateTime? localDateEnd, CaclTFBDetailsInput? tfbDetails)?, {required TResult orElse()}) → TResult -
Available on CaclInput, provided by the CaclInputPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this CaclInput to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? id, String? assetId, String? transportAssetId, String? transportUserId, String? caclNumber, CaclCategory? category, String? product, String? clientAssetId, String? tankNumber, String? transport, CaclEquipmentInput? equipments, MeasurementsInput? measurements, ResultsInput? results, CaclMeasurement? measurer01, CaclMeasurement? measurer02, VolumeMovedInput? volumeMoved, String? observations, DateTime? startedAt, DateTime? finishedAt, String? operationId, DateTime? localDateStart, DateTime? localDateEnd, CaclTFBDetailsInput? tfbDetails)) → TResult -
Available on CaclInput, provided by the CaclInputPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? id, String? assetId, String? transportAssetId, String? transportUserId, String? caclNumber, CaclCategory? category, String? product, String? clientAssetId, String? tankNumber, String? transport, CaclEquipmentInput? equipments, MeasurementsInput? measurements, ResultsInput? results, CaclMeasurement? measurer01, CaclMeasurement? measurer02, VolumeMovedInput? volumeMoved, String? observations, DateTime? startedAt, DateTime? finishedAt, String? operationId, DateTime? localDateStart, DateTime? localDateEnd, CaclTFBDetailsInput? tfbDetails)?) → TResult? -
Available on CaclInput, provided by the CaclInputPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited