Checkpoint class abstract
Checkpoint Checkpoint entity definition, it define the differents checkpoints for the asset tracking.
FIELDS
id ID ID of the checkpoint entity. This ID is unique.
name String Name of the checkpoint.
assetId ID Asset tag ID of the checkpoint.
waypointsJson Waypoint List of waypoints in the checkpoint. See the documention of the Type.
waypoints Waypoint List of waypoints in the checkpoint. See the documention of the Type.
cases Case List of cases occurred in the checkpoint
isActive Boolean Boolean value that determines if the checkpoint is active.
access AccessPermission
List of custom access permissions.
linkedAssetsIds LinkedAssetToCheckpointId IDs of the linked Assets.
- Available extensions
- Annotations
-
- @freezed
Constructors
-
Checkpoint({required String id, required String name, String? assetId, List<
Waypoint> ? waypoints, bool? isActive, List<Access> ? access, List<LinkedAssetToCheckpointId> ? linkedAssetsIds}) -
constfactory
-
Checkpoint.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
access
→ List<
Access> ? -
List of custom access permissions.
no setterinherited
- assetId → String?
-
Asset tag ID of the checkpoint.
no setterinherited
-
copyWith
→ $CheckpointCopyWith<
Checkpoint> -
Create a copy of Checkpoint
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
ID of the checkpoint entity. This ID is unique.
no setterinherited
- isActive → bool?
-
Boolean value that determines if the checkpoint is active.
no setterinherited
-
linkedAssetsIds
→ List<
LinkedAssetToCheckpointId> ? -
IDs of the linked Assets.
no setterinherited
- name → String
-
Name of the checkpoint.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
waypoints
→ List<
Waypoint> ? -
List of waypoints in the checkpoint. See the documention of the Type.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_Checkpoint value)) → TResult -
Available on Checkpoint, provided by the CheckpointPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_Checkpoint value)?) → TResult? -
Available on Checkpoint, provided by the CheckpointPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_Checkpoint value)?, {required TResult orElse()}) → TResult -
Available on Checkpoint, provided by the CheckpointPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String id, String name, String? assetId, List< Waypoint> ? waypoints, bool? isActive, List<Access> ? access, List<LinkedAssetToCheckpointId> ? linkedAssetsIds)?, {required TResult orElse()}) → TResult -
Available on Checkpoint, provided by the CheckpointPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this Checkpoint to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String id, String name, String? assetId, List< Waypoint> ? waypoints, bool? isActive, List<Access> ? access, List<LinkedAssetToCheckpointId> ? linkedAssetsIds)) → TResult -
Available on Checkpoint, provided by the CheckpointPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String id, String name, String? assetId, List< Waypoint> ? waypoints, bool? isActive, List<Access> ? access, List<LinkedAssetToCheckpointId> ? linkedAssetsIds)?) → TResult? -
Available on Checkpoint, provided by the CheckpointPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited