ConciergeFormBlock class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- ConciergeFormBlock({@JsonKey.new(unknownEnumValue: ConciergeFormBlockType.text) required ConciergeFormBlockType blockType, required String name, ConciergeFormBlockConfiguration? configuration, ConciergeFormBlockValidator? showWhen})
-
constfactory
-
ConciergeFormBlock.fromJson(Map<
String, dynamic> json) -
factory
Properties
- blockType → ConciergeFormBlockType
-
Is the type of the block
no setterinherited
- configuration → ConciergeFormBlockConfiguration?
-
Is the configuration of the block
no setterinherited
-
copyWith
→ $ConciergeFormBlockCopyWith<
ConciergeFormBlock> -
Create a copy of ConciergeFormBlock
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Is the title of the block
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showWhen → ConciergeFormBlockValidator?
-
Is the validator of the block
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ConciergeFormBlock value)) → TResult -
Available on ConciergeFormBlock, provided by the ConciergeFormBlockPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ConciergeFormBlock value)?) → TResult? -
Available on ConciergeFormBlock, provided by the ConciergeFormBlockPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ConciergeFormBlock value)?, {required TResult orElse()}) → TResult -
Available on ConciergeFormBlock, provided by the ConciergeFormBlockPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(ConciergeFormBlockType blockType, String name, ConciergeFormBlockConfiguration? configuration, ConciergeFormBlockValidator? showWhen)?, {required TResult orElse()}) → TResult -
Available on ConciergeFormBlock, provided by the ConciergeFormBlockPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ConciergeFormBlock to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(ConciergeFormBlockType blockType, String name, ConciergeFormBlockConfiguration? configuration, ConciergeFormBlockValidator? showWhen)) → TResult -
Available on ConciergeFormBlock, provided by the ConciergeFormBlockPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(ConciergeFormBlockType blockType, String name, ConciergeFormBlockConfiguration? configuration, ConciergeFormBlockValidator? showWhen)?) → TResult? -
Available on ConciergeFormBlock, provided by the ConciergeFormBlockPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited