DbPartition class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- DbPartition({required String id, required String parentTable, required String tableName, @Default.new(false) bool isCompleted, @Default.new(false) bool isDefault, @TimestampOrNullConverter() DateTime? startAt, @TimestampOrNullConverter() DateTime? endAt, int? numOfRecords, double? totalSize, double? sizePerRecord})
-
constfactory
-
DbPartition.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $DbPartitionCopyWith<
DbPartition> -
Create a copy of DbPartition
with the given fields replaced by the non-null parameter values.
no setterinherited
- endAt → DateTime?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setterinherited
- isCompleted → bool
-
no setterinherited
- isDefault → bool
-
no setterinherited
- numOfRecords → int?
-
no setterinherited
- parentTable → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizePerRecord → double?
-
no setterinherited
- startAt → DateTime?
-
no setterinherited
- tableName → String
-
no setterinherited
- totalSize → double?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_DbPartition value)) → TResult -
Available on DbPartition, provided by the DbPartitionPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_DbPartition value)?) → TResult? -
Available on DbPartition, provided by the DbPartitionPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_DbPartition value)?, {required TResult orElse()}) → TResult -
Available on DbPartition, provided by the DbPartitionPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String id, String parentTable, String tableName, bool isCompleted, bool isDefault, DateTime? startAt, DateTime? endAt, int? numOfRecords, double? totalSize, double? sizePerRecord)?, {required TResult orElse()}) → TResult -
Available on DbPartition, provided by the DbPartitionPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this DbPartition to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String id, String parentTable, String tableName, bool isCompleted, bool isDefault, DateTime? startAt, DateTime? endAt, int? numOfRecords, double? totalSize, double? sizePerRecord)) → TResult -
Available on DbPartition, provided by the DbPartitionPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String id, String parentTable, String tableName, bool isCompleted, bool isDefault, DateTime? startAt, DateTime? endAt, int? numOfRecords, double? totalSize, double? sizePerRecord)?) → TResult? -
Available on DbPartition, provided by the DbPartitionPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited