InboundProtocolInput class abstract
- Available extensions
- Annotations
-
- @unfreezed
Constructors
-
InboundProtocolInput({String? id, @Default.new('') String name, @ColorConverter() @Default.new(Colors.blue) Color color, @Default.new(true) bool isEnabled, @Default.new([]) List<
String> categoriesIds, @JsonKey.new(unknownEnumValue: OperationMode.unknown) @Default.new(OperationMode.realtime) OperationMode operationMode, @Default.new(false) bool hasNativeCommands, @Default.new(false) bool hasSmsCommands, @Default.new(false) bool hasCommandsResult, int? channelId, @Default.new(false) bool isFlespi, String? flespiId, @Default.new(false) bool hasAck, @Default.new('') String ackTopicFormat, @Default.new(false) bool isImported, @Default.new([]) List<CredentialFieldInput> requiredFields, @Default.new(false) bool canFota, String? host, int? port, String? mqttTopic, required AvatarInput dynamicIcon, String? cycleId, @Default.new(false) bool hasModbus, @Default.new([]) List<String> modbusPorts, @Default.new(false) bool requiresFlespiToken, @Default.new([]) List<FlespiAclInput> flespiAcl, WebhookStructureInput? webhookStructure, @Default.new(false) bool requiresExternalAccount, @Default.new(false) bool requiresStructure, @Default.new([]) List<CommandDefinitionInput> commandsStructure, @Default.new([]) List<ConfigGroupingInput> configStructure, @Default.new(false) bool confiotCapable, String? peripheralIdentifier, Map<String, dynamic> ? peripheralParserSpec}) -
factory
-
InboundProtocolInput.fromJson(Map<
String, dynamic> json) -
factory
Properties
- ackTopicFormat ↔ String
-
ackTopicFormatAck topic format. Only used for Flespi MQTT protocols.getter/setter pairinherited - canFota ↔ bool
-
canFotaBoolean that indicates if the protocol can be updated with FOTA (Firmware over the air).getter/setter pairinherited -
categoriesIds
↔ List<
String> -
categoriesIdsID of all categories assignedgetter/setter pairinherited - channelId ↔ int?
-
channelIdMQTT Channel ID. Only used for realtime protocols.GOLDEN M INTERNAL ONLYgetter/setter pairinherited - color ↔ Color
-
colorIndicates the color assigned to the protocolgetter/setter pairinherited -
commandsStructure
↔ List<
CommandDefinitionInput> -
commandsStructureis the structure of the commands for the protocol.getter/setter pairinherited -
configStructure
↔ List<
ConfigGroupingInput> -
configStructureis the structure of the configuration for the protocol.getter/setter pairinherited - confiotCapable ↔ bool
-
confiotCapableis the boolean that indicates if the protocol is capable of using the Confiot platform.getter/setter pairinherited -
copyWith
→ $InboundProtocolInputCopyWith<
InboundProtocolInput> -
Create a copy of InboundProtocolInput
with the given fields replaced by the non-null parameter values.
no setterinherited
- cycleId ↔ String?
-
cycleIdis the ID of the cycle to which the field belongs.getter/setter pairinherited - dynamicIcon ↔ AvatarInput
-
dynamicIconis the icon of the protocol.getter/setter pairinherited -
flespiAcl
↔ List<
FlespiAclInput> -
flespiAclrefers to the ACL for the token generation.getter/setter pairinherited - flespiId ↔ String?
-
flespiIdFlespi ID. Only used for Flespi protocols.getter/setter pairinherited - hasAck ↔ bool
-
hasAckBoolean that indicates if the protocol has ACK support.getter/setter pairinherited - hasCommandsResult ↔ bool
-
hasCommandsResultBoolean that indicates if the protocol has commands.getter/setter pairinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- hasModbus ↔ bool
-
hasModbusis the boolean that indicates if the protocol has support for Modbus.getter/setter pairinherited - hasNativeCommands ↔ bool
-
hasNativeCommandsBoolean that indicates if the protocol has commands though the native comm channel.getter/setter pairinherited - hasSmsCommands ↔ bool
-
hasSmsCommandsBoolean that indicates if the protocol has commands though SMS.getter/setter pairinherited - host ↔ String?
-
hostis the host of the server, means the IP or domain (or subdomain) of the server to send or receive the informationgetter/setter pairinherited - id ↔ String?
-
idID of the protocol entity. This ID is unique.getter/setter pairinherited - isEnabled ↔ bool
-
isEnabledBoolean that indicates if the protocol is enabled.getter/setter pairinherited - isFlespi ↔ bool
-
isFlespiBoolean that indicates if the protocol is from Flespi.getter/setter pairinherited - isImported ↔ bool
-
isImportedBoolean that indicates if the devices from this protocol are imported from external.getter/setter pairinherited -
modbusPorts
↔ List<
String> -
modbusPortsis the list of Modbus ports that the protocol has.getter/setter pairinherited - mqttTopic ↔ String?
-
mqttTopicis the MQTT topic to send or receive the informationgetter/setter pairinherited - name ↔ String
-
nameName of the protocol.getter/setter pairinherited - operationMode ↔ OperationMode
-
operationModeIndicates the operation mode of the protocol.getter/setter pairinherited - peripheralIdentifier ↔ String?
-
peripheralIdentifieris the identifier of the peripheral device.getter/setter pairinherited -
peripheralParserSpec
↔ Map<
String, dynamic> ? -
peripheralParserSpecis the parser specification for the peripheral device.getter/setter pairinherited - port ↔ int?
-
portis the port of the server, means the port of the server to send or receive the information 0 means in API and backend services "ignore this field"getter/setter pairinherited -
requiredFields
↔ List<
CredentialFieldInput> -
requiredFieldsRequired configuration fields.getter/setter pairinherited - requiresExternalAccount ↔ bool
-
requiresExternalAccountindicates if the protocol requires an external account to work.getter/setter pairinherited - requiresFlespiToken ↔ bool
-
requiresFlespiTokenindicates if the protocol requires a Flespi token to work.getter/setter pairinherited - requiresStructure ↔ bool
-
requiresStructureindicates if the protocol requires a structure to work.getter/setter pairinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- webhookStructure ↔ WebhookStructureInput?
-
webhookStructuredefines the specific methods required to handle a complete webhook operation.getter/setter pairinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_InboundProtocolInput value)) → TResult -
Available on InboundProtocolInput, provided by the InboundProtocolInputPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_InboundProtocolInput value)?) → TResult? -
Available on InboundProtocolInput, provided by the InboundProtocolInputPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_InboundProtocolInput value)?, {required TResult orElse()}) → TResult -
Available on InboundProtocolInput, provided by the InboundProtocolInputPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? id, String name, Color color, bool isEnabled, List< String> categoriesIds, OperationMode operationMode, bool hasNativeCommands, bool hasSmsCommands, bool hasCommandsResult, int? channelId, bool isFlespi, String? flespiId, bool hasAck, String ackTopicFormat, bool isImported, List<CredentialFieldInput> requiredFields, bool canFota, String? host, int? port, String? mqttTopic, AvatarInput dynamicIcon, String? cycleId, bool hasModbus, List<String> modbusPorts, bool requiresFlespiToken, List<FlespiAclInput> flespiAcl, WebhookStructureInput? webhookStructure, bool requiresExternalAccount, bool requiresStructure, List<CommandDefinitionInput> commandsStructure, List<ConfigGroupingInput> configStructure, bool confiotCapable, String? peripheralIdentifier, Map<String, dynamic> ? peripheralParserSpec)?, {required TResult orElse()}) → TResult -
Available on InboundProtocolInput, provided by the InboundProtocolInputPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this InboundProtocolInput to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? id, String name, Color color, bool isEnabled, List< String> categoriesIds, OperationMode operationMode, bool hasNativeCommands, bool hasSmsCommands, bool hasCommandsResult, int? channelId, bool isFlespi, String? flespiId, bool hasAck, String ackTopicFormat, bool isImported, List<CredentialFieldInput> requiredFields, bool canFota, String? host, int? port, String? mqttTopic, AvatarInput dynamicIcon, String? cycleId, bool hasModbus, List<String> modbusPorts, bool requiresFlespiToken, List<FlespiAclInput> flespiAcl, WebhookStructureInput? webhookStructure, bool requiresExternalAccount, bool requiresStructure, List<CommandDefinitionInput> commandsStructure, List<ConfigGroupingInput> configStructure, bool confiotCapable, String? peripheralIdentifier, Map<String, dynamic> ? peripheralParserSpec)) → TResult -
Available on InboundProtocolInput, provided by the InboundProtocolInputPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? id, String name, Color color, bool isEnabled, List< String> categoriesIds, OperationMode operationMode, bool hasNativeCommands, bool hasSmsCommands, bool hasCommandsResult, int? channelId, bool isFlespi, String? flespiId, bool hasAck, String ackTopicFormat, bool isImported, List<CredentialFieldInput> requiredFields, bool canFota, String? host, int? port, String? mqttTopic, AvatarInput dynamicIcon, String? cycleId, bool hasModbus, List<String> modbusPorts, bool requiresFlespiToken, List<FlespiAclInput> flespiAcl, WebhookStructureInput? webhookStructure, bool requiresExternalAccount, bool requiresStructure, List<CommandDefinitionInput> commandsStructure, List<ConfigGroupingInput> configStructure, bool confiotCapable, String? peripheralIdentifier, Map<String, dynamic> ? peripheralParserSpec)?) → TResult? -
Available on InboundProtocolInput, provided by the InboundProtocolInputPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited