hasNativeCommands property
hasNativeCommands Boolean that indicates if the protocol has commands though the native comm channel.
Implementation
@JsonKey(unknownEnumValue: OperationMode.unknown) set operationMode(OperationMode value);/// [hasNativeCommands] Boolean that indicates if the protocol has commands though the native comm channel.
bool get hasNativeCommands;
hasNativeCommands Boolean that indicates if the protocol has commands though the native comm channel.
Implementation
bool get hasNativeCommands;/// [hasNativeCommands] Boolean that indicates if the protocol has commands though the native comm channel.
set hasNativeCommands(bool value);