functionCode property
functionCode is the function code of the modbus device.
This value is a Hexadecimal number from 0x01 to 0xFF inclusive, the stored value shouldn't be prefixed with 0x.
Implementation
set controllerAddress(String value);/// [functionCode] is the function code of the modbus device.
/// This value is a Hexadecimal number from 0x01 to 0xFF inclusive, the stored value shouldn't be prefixed with 0x.
String get functionCode;
functionCode is the function code of the modbus device.
This value is a Hexadecimal number from 0x01 to 0xFF inclusive, the stored value shouldn't be prefixed with 0x.
Implementation
String get functionCode;/// [functionCode] is the function code of the modbus device.
/// This value is a Hexadecimal number from 0x01 to 0xFF inclusive, the stored value shouldn't be prefixed with 0x.
set functionCode(String value);