ReferenceVariant enum
Values
- standard → const ReferenceVariant
-
Defines the standard variant of a reference, used in most of the Layrz Apps.
- mappit → const ReferenceVariant
-
Defines the variant used on Mappit ecosystem
- sdm → const ReferenceVariant
-
Defines the variant used on SDM ecosystem
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ReferenceVariant> - A constant List of the values in this enum, in order of their declaration.