SensorGridItemType enum
Values
- plain → const SensorGridItemType
-
plain represents a plain sensor, direct text representation of the value
- gauge → const SensorGridItemType
-
gauge represents a gauge sensor, a visual representation of the value as a gauge
- ranging → const SensorGridItemType
-
ranging similar to gauge but with a different visual representation. Instead of divisions, uses a range of values to represent the sensor value.
- speedometer → const SensorGridItemType
-
speedometer represents a speedometer sensor, a visual representation of the value as a speedometer with a needle and divisions.
- thermometer → const SensorGridItemType
-
thermometer represents a thermometer sensor, a visual representation of the value as a thermometer with a needle and divisions.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - toJson returns the string representation of the enum value.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
String json) → SensorGridItemType - fromJson returns the enum value from a string representation.
Constants
-
values
→ const List<
SensorGridItemType> - A constant List of the values in this enum, in order of their declaration.