TenvioOrder class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
TenvioOrder({required String id, required String ownerId, required Asset warehouse, required String warehouseId, String? qrCode, @TenvioOrderStatusConverter() required TenvioOrderStatus status, @TenvioDestinationTypeOrNullConverter() TenvioDestinationType? destinationType, Asset? destinationWarehouse, String? destinationWarehouseId, User? destinationUser, String? destinationUserId, TenvioUnregisteredUser? destinationUnregistered, @Default.new([]) List<
String> notes, bool? requiresPhotos, bool? highPriority, List<User> ? packers, List<String> ? packersIds, List<TenvioItemQuantity> ? itemQuantities, List<TenvioItem> ? items, String? packedImage, List<TenvioPhotos> ? statusPhotos, @TimestampOrNullConverter() DateTime? createdAt, @TimestampOrNullConverter() DateTime? updatedAt}) -
constfactory
-
TenvioOrder.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $TenvioOrderCopyWith<
TenvioOrder> -
Create a copy of TenvioOrder
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime?
-
createdAtCreation date of the order.no setterinherited - destinationType → TenvioDestinationType?
-
destinationTypeType of the destination.no setterinherited - destinationUnregistered → TenvioUnregisteredUser?
-
destinationUnregisteredUserUnregistered user destination of the order.no setterinherited - destinationUser → User?
-
destinationUserUser destination of the order.no setterinherited - destinationUserId → String?
-
destinationUserIdID of the user destination of the order.no setterinherited - destinationWarehouse → Asset?
-
destinationWarehouseWarehouse destination of the order.no setterinherited - destinationWarehouseId → String?
-
destinationWarehouseIdID of the warehouse destination of the order.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- highPriority → bool?
-
highhighPriorityHigh priority indicator.no setterinherited - id → String
-
idID of the order entity. This ID is unique along the system.no setterinherited -
itemQuantities
→ List<
TenvioItemQuantity> ? -
itemQuantitiesItems included in the order.no setterinherited -
items
→ List<
TenvioItem> ? -
itemsItems included in the order.no setterinherited -
notes
→ List<
String> -
notesNotes of the order entity.no setterinherited - orderId → String
-
no setter
- ownerId → String
-
ownerIdID of the owner of the order.no setterinherited - packedImage → String?
-
packedImageURL of the packed image.no setterinherited -
packers
→ List<
User> ? -
packersPackers assigned to the order.no setterinherited -
packersIds
→ List<
String> ? -
packersIdsIDs of packers assigned to the order.no setterinherited - qrCode → String?
-
qrCodeis the QR code of the order. should contains the following URI:tenvio://orders/:idno setterinherited - requiresPhotos → bool?
-
requiresImagesRequires images indicator.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → TenvioOrderStatus
-
statusStatus of the order entity.no setterinherited -
statusPhotos
→ List<
TenvioPhotos> ? -
statusPhotosStatus photos of the order.no setterinherited - updatedAt → DateTime?
-
updatedAtLast update date of the order.no setterinherited - warehouse → Asset
-
warehousewhere the order is located.no setterinherited - warehouseId → String
-
warehouseIdID of the warehouse where the order is located.no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_TenvioOrder value)) → TResult -
Available on TenvioOrder, provided by the TenvioOrderPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_TenvioOrder value)?) → TResult? -
Available on TenvioOrder, provided by the TenvioOrderPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_TenvioOrder value)?, {required TResult orElse()}) → TResult -
Available on TenvioOrder, provided by the TenvioOrderPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String id, String ownerId, Asset warehouse, String warehouseId, String? qrCode, TenvioOrderStatus status, TenvioDestinationType? destinationType, Asset? destinationWarehouse, String? destinationWarehouseId, User? destinationUser, String? destinationUserId, TenvioUnregisteredUser? destinationUnregistered, List< String> notes, bool? requiresPhotos, bool? highPriority, List<User> ? packers, List<String> ? packersIds, List<TenvioItemQuantity> ? itemQuantities, List<TenvioItem> ? items, String? packedImage, List<TenvioPhotos> ? statusPhotos, DateTime? createdAt, DateTime? updatedAt)?, {required TResult orElse()}) → TResult -
Available on TenvioOrder, provided by the TenvioOrderPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this TenvioOrder to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String id, String ownerId, Asset warehouse, String warehouseId, String? qrCode, TenvioOrderStatus status, TenvioDestinationType? destinationType, Asset? destinationWarehouse, String? destinationWarehouseId, User? destinationUser, String? destinationUserId, TenvioUnregisteredUser? destinationUnregistered, List< String> notes, bool? requiresPhotos, bool? highPriority, List<User> ? packers, List<String> ? packersIds, List<TenvioItemQuantity> ? itemQuantities, List<TenvioItem> ? items, String? packedImage, List<TenvioPhotos> ? statusPhotos, DateTime? createdAt, DateTime? updatedAt)) → TResult -
Available on TenvioOrder, provided by the TenvioOrderPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String id, String ownerId, Asset warehouse, String warehouseId, String? qrCode, TenvioOrderStatus status, TenvioDestinationType? destinationType, Asset? destinationWarehouse, String? destinationWarehouseId, User? destinationUser, String? destinationUserId, TenvioUnregisteredUser? destinationUnregistered, List< String> notes, bool? requiresPhotos, bool? highPriority, List<User> ? packers, List<String> ? packersIds, List<TenvioItemQuantity> ? itemQuantities, List<TenvioItem> ? items, String? packedImage, List<TenvioPhotos> ? statusPhotos, DateTime? createdAt, DateTime? updatedAt)?) → TResult? -
Available on TenvioOrder, provided by the TenvioOrderPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited